<?
######## Confixx(R) 3.2.1 Professional ############
####### Copyright SWsoft, Inc. 2004-2006 ##########
##### http://www.swsoft.com - info@swsoft.com #####

$lang_text['add_area'] = 'Add value';
$lang_text['alab_button1'] = 'Start export';
$lang_text['alab_cell_exportall'] = 'Export all (first export)';
$lang_text['alab_cell_exportstart'] = 'Export beginning with';
$lang_text['alab_cell_le'] = 'Last export';
$lang_text['alab_cell_title1'] = 'Export of billing data';
$lang_text['alab_link1'] = 'Export settings';
$lang_text['alab_title1'] = 'Billing / data export';
$lang_text['alabei2_error1'] = 'You must specify a server name so that the billing software can clearly assign this server. You may only use this server name on this server, not on any others. The server name must consist of at least 4 characters.';
$lang_text['alabei2_error2'] = 'Please enter a valid e-mail address.';
$lang_text['alabei2_error3'] = 'The settings have been saved.';
$lang_text['alabei2_errortitle'] = 'Notice:';
$lang_text['alabei_button1'] = 'Save';
$lang_text['alabei_cell_email'] = 'E-mail (recipient)';
$lang_text['alabei_cell_servername'] = 'Server name';
$lang_text['alabei_cell_title1'] = 'Settings';
$lang_text['alabei_descr1'] = 'Enter a <b>clearly identifiable server name</b>. The server name is necessary to clearly identify your server. Do not change the name of the server after the first export.</p><p>The export data will be sent to the e-mail address specified in this section. Set up an e-mail address and a POP3 box on one of your servers for exporting the data. The export data of several servers can be sent to the same e-mail address.';
$lang_text['alabei_title1'] = 'Billing / data export';
$lang_text['alabex_error1'] = 'You must specify a server name so that the billing software can clearly assign this server. You may only use this server name on this server, not on any others. The server name must consist of at least 4 characters.';
$lang_text['alabex_error2'] = 'Please enter a valid e-mail address.';
$lang_text['alpw2_error1'] = 'The old password does not match the password on file. Please complete the form again.';
$lang_text['alpw2_error3'] = 'The two new passwords do not match. Please complete the form again.';
$lang_text['alpw2_error4'] = 'Your password must consist of at least 6 characters and no more than 12 characters. Please complete the form again.';
$lang_text['alpw2_error5'] = 'Your data have been changed.';
$lang_text['alpw2_error6'] = 'Your login may only consist of letters and numbers. Please complete the form again.';
$lang_text['alpw2_error7'] = 'Your login must consist of at least 3 characters and no more than 27 characters. Please complete the form again.';
$lang_text['alpw2_errortitle'] = 'Notice:';
$lang_text['alpw_button1'] = 'Change password';
$lang_text['alpw_cell_login'] = 'Username';
$lang_text['alpw_cell_oldpw'] = 'Old password';
$lang_text['alpw_cell_pw1'] = 'New password';
$lang_text['alpw_cell_pw2'] = 'Re-enter password';
$lang_text['alpw_descr1'] = 'Please fill in this form and confirm with &quot;Change password&quot;. If you only want to change your user name, please leave the password information blank.';
$lang_text['alpw_descr2'] = 'This password gives you access to the admin, reseller and user sections and to the users\' Webalizer stats.';
$lang_text['alpw_title1'] = 'Change password';
$lang_text['alse2_cell_error'] = 'Message';
$lang_text['alse2_cell_script'] = 'Script';
$lang_text['alse2_cell_time'] = 'Time';
$lang_text['alse2_error1'] = 'No messages available.';
$lang_text['alse2_error2'] = 'No notices available at the moment.';
$lang_text['alse2_error3'] = 'There are no error messages at the moment.';
$lang_text['alse2_error4'] = 'There are no warnings at the moment.';
$lang_text['alse2_link_back'] = 'back';
$lang_text['alse2_link_next'] = 'next';
$lang_text['alse2_link_select'] = 'Selection';
$lang_text['alse2_subtitle1'] = 'Messages';
$lang_text['alse2_title'] = 'Messages';
$lang_text['alse_button1'] = 'View';
$lang_text['alse_cell_number'] = 'Number of messages';
$lang_text['alse_cell_type'] = 'Type';
$lang_text['alse_descr1'] = 'These messages are issued by the Confixx update script in various situations. Select the type and number of messages you want to view.';
$lang_text['alse_descr2'] = 'It is imperative that you detect the cause of and remove these serious errors. Errors will cause the Confixx update script to abort execution. System changes can therefore be executed only partially or not at all.';
$lang_text['alse_descr3'] = 'Warnings are produced, for example, when a directory could not be created or deleted. The Confixx update script will not abort due to warnings. If warnings are produced, you should attempt to correct the described problem manually afterwards.';
$lang_text['alse_descr4'] = 'Notices are used for logging. They are generated when users, sub-domains etc., are created or deleted.';
$lang_text['alse_select_error'] = 'Error';
$lang_text['alse_select_notice'] = 'Notices';
$lang_text['alse_select_warning'] = 'Warnings';
$lang_text['alse_title1'] = 'Messages';
$lang_text['alse_title2'] = 'There are three types of messages:';
$lang_text['alse_title3'] = 'Error:';
$lang_text['alse_title4'] = 'Warnings:';
$lang_text['alse_title5'] = 'Notices:';
$lang_text['alsp2_error1'] = 'Invalid language selection. The language has not been changed.';
$lang_text['alsp_button1'] = 'Change';
$lang_text['alsp_cell_language'] = 'Language';
$lang_text['alsp_cell_oldskins'] = 'Use old skins';
$lang_text['alsp_cell_treemenu'] = 'Tree menu';
$lang_text['alsp_descr1'] = 'Select a language for your Confixx web interface. The language settings of other users (resellers, end users, POP3 users etc.) will not be changed by this setting.';
$lang_text['alsp_title1'] = 'Language';
$lang_text['alsr_baddb'] = 'Testing connection to server $VAR[0] failed. Possibly, you specified an incorrect data. Do you want to go back and edit the data?';
$lang_text['alsr_cell_add'] = 'add';
$lang_text['alsr_cell_dbname'] = 'db name';
$lang_text['alsr_cell_delete'] = 'remove';
$lang_text['alsr_cell_delete_quest'] = 'Delete?';
$lang_text['alsr_cell_edit'] = 'edit';
$lang_text['alsr_cell_editdata'] = 'edit data';
$lang_text['alsr_cell_ip'] = 'ip/dns-name';
$lang_text['alsr_cell_name'] = 'servername';
$lang_text['alsr_cell_nr'] = 'no.';
$lang_text['alsr_cell_password'] = 'db password';
$lang_text['alsr_cell_port'] = 'db port';
$lang_text['alsr_cell_save'] = 'Save';
$lang_text['alsr_cell_saveanyway'] = 'save anyway';
$lang_text['alsr_cell_select'] = 'select';
$lang_text['alsr_cell_testconn'] = 'Test connection';
$lang_text['alsr_cell_user'] = 'db username';
$lang_text['alsr_descr1'] = 'Here you can administrate your list of Parallels Confixx servers. You can add, edit or remove a single server. To work with one server choose <b>select</b>.';
$lang_text['alsr_descr2'] = 'Click <a href="$VAR[0]">here</a> to add a new server.';
$lang_text['alsr_descr3'] = 'Click here to select the Parallels Confixx server on which Confixx Business is running';
$lang_text['alsr_title1'] = 'Confixx server list';
$lang_text['alst_cell_atdomains'] = 'Number of at-domains';
$lang_text['alst_cell_countdu'] = 'Determine used storage space';
$lang_text['alst_cell_cron'] = 'Cron jobs';
$lang_text['alst_cell_domains'] = 'Number of domains';
$lang_text['alst_cell_du'] = 'Used storage space';
$lang_text['alst_cell_emailalias'] = 'E-mail aliases';
$lang_text['alst_cell_event'] = 'Event';
$lang_text['alst_cell_ftptraffic'] = 'Measure FTP traffic';
$lang_text['alst_cell_httpdreload'] = 'Web server reload';
$lang_text['alst_cell_idn'] = 'National domains';
$lang_text['alst_cell_iptraffic'] = 'Measure IP traffic';
$lang_text['alst_cell_lastrun1'] = 'last SCHEDULED run';
$lang_text['alst_cell_lastrun2'] = 'last ACTUAL run';
$lang_text['alst_cell_maillist'] = 'Mailing lists';
$lang_text['alst_cell_mailtraffic'] = 'Measure mail traffic';
$lang_text['alst_cell_mysql'] = 'MySQL databases';
$lang_text['alst_cell_nextrun'] = 'next run';
$lang_text['alst_cell_reseller'] = 'Number of resellers';
$lang_text['alst_cell_servername'] = 'Server name';
$lang_text['alst_cell_shareddomains'] = 'Number of shared domains';
$lang_text['alst_cell_space'] = 'Assigned storage space';
$lang_text['alst_cell_stddomain'] = 'Standard domain';
$lang_text['alst_cell_subdomains'] = 'Number of sub-domains';
$lang_text['alst_cell_traffic'] = 'Traffic $VAR[0] $VAR[1]';
$lang_text['alst_cell_updatescript'] = 'Update script';
$lang_text['alst_cell_user'] = 'Number of users';
$lang_text['alst_cell_webtraffic'] = 'Measure web traffic';
$lang_text['alst_cell_wildcards'] = 'Number of wildcards';
$lang_text['alst_descr1'] = 'the execution of the script should have started at this time. If this time does not correspond to the ACTUAL run, it was not executed because it was not necessary.';
$lang_text['alst_descr2'] = 'the execution of the script was started at this time. It was completely executed and has made changes to the system.';
$lang_text['alst_lastrun1'] = 'SCHEDULED run: ';
$lang_text['alst_lastrun2'] = 'ACTUAL run: ';
$lang_text['alst_servertime'] = 'Server time';
$lang_text['alst_title1'] = 'General information';
$lang_text['alst_title2'] = 'You are logged in as administrator';
$lang_text['alst_title3'] = 'Confixx scripts execution times';
$lang_text['anae_button1'] = '<b>Next</b>';
$lang_text['anae_cell_block'] = 'Lock/unlock reseller';
$lang_text['anae_cell_del'] = 'Delete reseller';
$lang_text['anae_cell_dns'] = 'alter DNS';
$lang_text['anae_cell_features'] = 'Change services';
$lang_text['anae_cell_ip'] = 'Edit IP addresses';
$lang_text['anae_cell_password'] = 'Change password';
$lang_text['anae_cell_person'] = 'Change personal data';
$lang_text['anae_cell_reseller'] = 'Reseller';
$lang_text['anae_cell_status'] = 'S';
$lang_text['anae_cell_title1'] = 'Select an action for a reseller';
$lang_text['anae_link1'] = 'Show reseller list';
$lang_text['anae_status_active'] = 'Reseller is active. Click to lock.';
$lang_text['anae_status_locked'] = 'Reseller is locked. Click to unlock';
$lang_text['anae_title1'] = 'Change reseller data';
$lang_text['anaefw_error1'] = 'This is not a valid reseller. Please check your entry.';
$lang_text['anaefw_error2'] = '<b>$VAR[0]</b> users have been assigned to the reseller. You can only delete resellers if they no longer have users assigned to them. Please delete the reseller\'s users or assign them to another reseller.';
$lang_text['anaefw_error3'] = 'Please select an action.';
$lang_text['anaeip2_error1'] = 'Your changes have been saved.';
$lang_text['anaeip2_error3'] = 'IP address <b>$VAR[0]</b> could not be deleted because user(s) <b>$VAR[1]</b> is using it as standard IP.<br>You must use "Set new standard IP for all of reseller\'s users using the standard IP." option.';
$lang_text['anaeip2_errortitle'] = 'Notice:';
$lang_text['anaeip_all'] = 'Set new standard IP for all of reseller\'s users using the standard IP.';
$lang_text['anaeip_button1'] = 'Save IP addresses';
$lang_text['anaeip_cell_descr1'] = 'Make multiple selections by pressing the &lt;ctrl&gt;-key and a mouse button.';
$lang_text['anaeip_cell_descr2'] = 'No other IP addresses available.';
$lang_text['anaeip_cell_descr3'] = 'There are no IP addresses.';
$lang_text['anaeip_cell_description'] = 'Label';
$lang_text['anaeip_cell_input'] = 'Input';
$lang_text['anaeip_cell_ip'] = 'IP addresses';
$lang_text['anaeip_cell_question'] = 'Which IP address do you want to use as the standard IP for <br> the reseller?';
$lang_text['anaeip_descr1'] = 'You can choose from the list which IP addresses will be available to the reseller.';
$lang_text['anaeip_select_stdip'] = 'Standard server IP';
$lang_text['anaeip_title1'] = 'Change reseller';
$lang_text['anaele2_err_cronjobs'] = 'You cannot set a limit for maximum number of cron jobs because the reseller has already assigned unlimited number of cron jobs to a user. Limit the number of cron jobs for this user.';
$lang_text['anaele2_err_cronjobs_2'] = 'You cannot set a limit for maximum number of cron jobs = $VAR[0] and hard limit because the reseller has already assigned $VAR[1]  number of cron jobs to users. ';
$lang_text['anaele2_err_domains'] = 'You cannot set a limit for maximum number of domains = $VAR[0] and hard limit because the reseller has already assigned $VAR[1]  number of domains to users.';
$lang_text['anaele2_err_kunden'] = 'You cannot set limit for maximum number of users = $VAR[0] and hard limit because the reseller has already created $VAR[1] number of users.';
$lang_text['anaele2_err_maillist'] = 'You cannot set a limit for maximum number of mailling lists because the reseller has already assigned unlimited number of mailling lists to a user. Limit the number of mailing lists for this user.';
$lang_text['anaele2_err_maillist_2'] = 'You cannot set a limit for maximum number of mailling lists = $VAR[0] and hard limit because the reseller has already assigned $VAR[1]  number of mailling lists to users. ';
$lang_text['anaele2_err_shareddomains'] = 'You cannot set a limit for maximum number of shared domains = $VAR[0] and hard limit because the reseller has already assigned $VAR[1] number of shared domains to users.';
$lang_text['anaele2_err_webapp'] = 'You cannot set a maximum limit for maximum number of Web Applications because the reseller has already assigned unlimited  number of Web Applications to a user. Limit the number of Web Applications for this user.';
$lang_text['anaele2_err_webapp_2'] = 'You cannot set a limit for maximum number of Web Applications = $VAR[0] and hard limit because the reseller has already assigned $VAR[1]  number of Web Applications to users. ';
$lang_text['anaele2_error1'] = 'You cannot set the maximum number of users to unlimited and set a limit at the same time.';
$lang_text['anaele2_error10'] = 'You cannot set the maximum number of FTP users to unlimited and set a limit at the same time.';
$lang_text['anaele2_error11'] = 'You cannot set a maximum number of FTP users because the reseller has already authorized an unlimited number of FTP users for a user. Specify the number of FTP users for this user.';
$lang_text['anaele2_error11_2'] = 'You cannot set a limit number of FTP users = $VAR[1] and hard limit because the reseller has already authorized $VAR[1] users for users.';
$lang_text['anaele2_error12'] = 'You cannot allow additional FTP users when FTP has been deactivated.';
$lang_text['anaele2_error13'] = 'You cannot set the maximum number of domains to unlimited and set a limit at the same time.';
$lang_text['anaele2_error14'] = 'You cannot set the maximum number of sub-domains to unlimited and set a limit at the same time.';
$lang_text['anaele2_error15'] = 'You cannot set a maximum number of sub-domains because the reseller has already authorized an unlimited number of sub-domains for a user. Specify the number of sub-domains for this user.';
$lang_text['anaele2_error15_2'] = 'You cannot set a limit number of sub-domains = $VAR[0] and hard limit because the reseller has already authorized $VAR[1] sub-domains for users.';
$lang_text['anaele2_error16'] = 'You cannot set the maximum number of MySQL databases to unlimited and set a limit at the same time.';
$lang_text['anaele2_error17'] = 'You cannot set a maximum number of MySQL databases because the reseller has already authorized an unlimited number of MySQL databases for a user. Specify the number of MySQL databases for this user.';
$lang_text['anaele2_error17_2'] = 'You cannot set a limit number of MySQL databases = $VAR[0] and hard limit because the reseller has already authorized $VAR[1] MySQL databases for users.';
$lang_text['anaele2_error18'] = 'You can allow standard CGI scripts only if you activate Perl for the reseller as well.';
$lang_text['anaele2_error19'] = 'You can authorize Shell access for the reseller only if the reseller is allowed to use FTP as well.';
$lang_text['anaele2_error2'] = 'You cannot set the maximum storage space to unlimited and set a limit at the same time.';
$lang_text['anaele2_error20'] = 'You have entered an incorrect value in the number of possible users. Please enter only whole numbers.';
$lang_text['anaele2_error21'] = 'Please enter an integer number in maximum storage space.';
$lang_text['anaele2_error22'] = 'You must assign at least 1 MB storage space to a reseller.';
$lang_text['anaele2_error23'] = 'Please enter a valid number for the maximum number of POP3 users.';
$lang_text['anaele2_error24'] = 'Please enter a valid number for the maximum number of e-mail addresses.';
$lang_text['anaele2_error25'] = 'You must authorize at least as many e-mail addresses as POP3 boxes.';
$lang_text['anaele2_error26'] = 'Please enter a valid number for the maximum number of e-mail autoresponders.';
$lang_text['anaele2_error27'] = 'You must authorize at least as many e-mail addresses as e-mail autoresponders.';
$lang_text['anaele2_error28'] = 'Please enter a valid number for the maximum number of FTP users.';
$lang_text['anaele2_error29'] = 'Please enter a valid number for the upper limit on traffic.';
$lang_text['anaele2_error3'] = 'You cannot set a maximum limit for storage space because the reseller has already assigned unlimited storage space to a user. Limit the storage space for this user.';
$lang_text['anaele2_error30'] = 'Please enter a valid number for the upper limit on traffic.';
$lang_text['anaele2_error31'] = 'You must authorize at least as many domains as users.';
$lang_text['anaele2_error32'] = 'Please enter a valid number for the maximum number of domains.';
$lang_text['anaele2_error33'] = 'Please enter a valid number for the maximum number of sub-domains.';
$lang_text['anaele2_error34'] = 'The number of wildcard sub-domains may not exceed the number of users the reseller is authorized to create, as each user can only use one wildcard sub-domain.';
$lang_text['anaele2_error35'] = 'The number of wildcard sub-domains may not exceed the number of sub-domains the reseller is authorized to assign.';
$lang_text['anaele2_error36'] = 'Please enter a valid number for the maximum number of MySQL databases.';
$lang_text['anaele2_error37'] = 'You must activate MySQL to authorize the reseller to assign external MySQL access.';
$lang_text['anaele2_error38'] = 'You must activate PHP if you want to activate PHP upload.';
$lang_text['anaele2_error39'] = 'The data have been saved.';
$lang_text['anaele2_error3_2'] = 'You cannot set a limit for storage space = $VAR[0] and hard limit because the reseller has already assigned $VAR[1] storage space to users.';
$lang_text['anaele2_error4'] = 'You cannot set the maximum number of POP3 boxes to unlimited and set a limit at the same time.';
$lang_text['anaele2_error40'] = 'You must activate DNS to activate DNR.';
$lang_text['anaele2_error41'] = 'You cannot set the maximum number of national domains to unlimited and set a limit at the same time.';
$lang_text['anaele2_error42'] = 'Please enter a valid number for the maximum number of national domains.';
$lang_text['anaele2_error43'] = 'You cannot set the maximum number of cron jobs to unlimited and set a limit at the same time.';
$lang_text['anaele2_error44'] = 'Please enter a valid number for the maximum number of cron jobs.';
$lang_text['anaele2_error45'] = 'You cannot set the maximum number of at-domains to unlimited and set a limit at the same time.';
$lang_text['anaele2_error46'] = 'You cannot set a maximum number of at-domains because the reseller has already authorized an unlimited number of at-domains for a user. Specify the number of at-domains for this user.';
$lang_text['anaele2_error46_2'] = 'You cannot set a limit number of at-domains = $VAR[0] and hard limit because the reseller has already authorized $VAR[1] at-domains for users.';
$lang_text['anaele2_error47'] = 'You cannot set the maximum number of wildcard sub-domains to unlimited and set a limit at the same time.';
$lang_text['anaele2_error48'] = 'You cannot set a maximum number of wildcard sub-domains because the reseller has already authorized an unlimited number of wildcard sub-domains for a user. Specify the number of wildcard sub-domains for this user.';
$lang_text['anaele2_error48_2'] = 'You cannot set a limit number of wildcard sub-domains = $VAR[0] and hard limit because the reseller has already authorized an unlimited $VAR[1] wildcard sub-domains for users.';
$lang_text['anaele2_error49'] = 'Please enter a valid number for the maximum number of wildcard sub-domains.';
$lang_text['anaele2_error5'] = 'You cannot set a maximum number of POP3 boxes because the reseller has already authorized an unlimited number of POP3 boxes for a user. Specify the number of POP3 boxes for this user.';
$lang_text['anaele2_error50'] = 'Please enter a valid number for the maximum number of at-domains.';
$lang_text['anaele2_error51'] = 'You cannot set  limit for mail space because the reseller has already assigned unlimited mail space to a user. Limit the mail space for this user.';
$lang_text['anaele2_error51_2'] = 'You cannot set a limit for mail space = $VAR[0] and hard limit because the reseller has already assigned $VAR[1] mail space to user.';
$lang_text['anaele2_error53'] = 'You cannot set a maximum number of shared domains because the reseller has already authorized an unlimited number of shared domains for a user. Specify the number of shared domains for this user.';
$lang_text['anaele2_error53_2'] = 'You cannot set a limit number of shared domains = $VAR[0] and hard limit because the reseller has already authorized $VAR[1] shared -domains for users.';
$lang_text['anaele2_error5_2'] = 'You cannot set a limit number of POP3 boxes = $VAR[0] and hard limit because the reseller has already authorized $VAR[1] POP3 boxes for users.';
$lang_text['anaele2_error6'] = 'You cannot set the maximum number of e-mail addresses to unlimited and set a limit at the same time.';
$lang_text['anaele2_error7'] = 'You cannot set a maximum number of e-mail addresses because the reseller has already authorized an unlimited number of e-mail addresses for a user. Specify the number of e-mail addresses for this user.';
$lang_text['anaele2_error7_2'] = 'You cannot set a limit number of e-mail addresses = $VAR[0] and hard limit because the reseller has already authorized $VAR[1] number of e-mail addresses for users.';
$lang_text['anaele2_error8'] = 'You cannot set the maximum number of e-mail autoresponders to unlimited and set a limit at the same time.';
$lang_text['anaele2_error9'] = 'You cannot set a limit for the maximum number of e-mail autoresponders because the reseller has already authorized an unlimited number of e-mail autoresponders for a user. Specify a limit for the number of e-mail autoresponders for this user.';
$lang_text['anaele2_error9_2'] = 'You cannot set a limit for the maximum number of e-mail autoresponders  = $VAR[0] and hard limit  because the reseller has already authorized $VAR[1] of e-mail autoresponders for users.';
$lang_text['anaele2_error_shareddomains'] = 'You cannot set the maximum number of shared domains to unlimited and set a limit at the same time.';
$lang_text['anaele2_errortitle'] = 'Notice:';
$lang_text['anaele_button1'] = 'Save data';
$lang_text['anaele_cell_atdomains'] = 'At-domains';
$lang_text['anaele_cell_autoresponder'] = 'Number of e-mail autoresponders';
$lang_text['anaele_cell_cgi'] = 'CGI / Perl';
$lang_text['anaele_cell_coldfusion'] = 'ColdFusion';
$lang_text['anaele_cell_cron'] = 'Cron jobs';
$lang_text['anaele_cell_dbext'] = 'External MySQL access';
$lang_text['anaele_cell_description'] = 'Label';
$lang_text['anaele_cell_dirlist'] = 'Directory listing';
$lang_text['anaele_cell_dnr'] = 'DNR';
$lang_text['anaele_cell_dns'] = 'DNS';
$lang_text['anaele_cell_domains'] = 'Creatable domains';
$lang_text['anaele_cell_email'] = 'Number of e-mail addresses';
$lang_text['anaele_cell_errorfiles'] = 'Define error files';
$lang_text['anaele_cell_frontpage'] = 'FrontPage Support';
$lang_text['anaele_cell_ftp'] = 'FTP';
$lang_text['anaele_cell_ftpusers'] = 'Number of additional FTP users';
$lang_text['anaele_cell_idn'] = 'National domains';
$lang_text['anaele_cell_input'] = 'Input';
$lang_text['anaele_cell_limit'] = 'Limit';
$lang_text['anaele_cell_maximum'] = 'maximum';
$lang_text['anaele_cell_maxusers'] = 'Maximum number of users';
$lang_text['anaele_cell_modpython'] = 'Module mod_python';
$lang_text['anaele_cell_mysql'] = 'MySQL Databases';
$lang_text['anaele_cell_php'] = 'PHP';
$lang_text['anaele_cell_phpupload'] = 'PHP upload';
$lang_text['anaele_cell_pop3'] = 'Number of POP3 mail boxes';
$lang_text['anaele_cell_pwdir'] = 'PW-protected directories';
$lang_text['anaele_cell_scponly'] = 'Scp/SFTP';
$lang_text['anaele_cell_shell'] = 'Shell access';
$lang_text['anaele_cell_space'] = 'Storage space';
$lang_text['anaele_cell_ssi'] = 'SSI';
$lang_text['anaele_cell_ssl'] = 'SSL';
$lang_text['anaele_cell_stdscripts'] = 'Standard CGI scripts';
$lang_text['anaele_cell_subdomains'] = 'Creatable sub-domains';
$lang_text['anaele_cell_traffic'] = 'Traffic contained';
$lang_text['anaele_cell_wap'] = 'WAP';
$lang_text['anaele_cell_webalizer'] = 'Webalizer / Stats';
$lang_text['anaele_cell_webftp'] = 'WebFTP';
$lang_text['anaele_cell_webmail'] = 'WebMail';
$lang_text['anaele_cell_wildcard'] = 'Wildcard sub-domains';
$lang_text['anaele_title1'] = 'Change reseller';
$lang_text['anaeli_cell_firm'] = 'Company (if specified)';
$lang_text['anaeli_cell_reseller'] = 'Reseller';
$lang_text['anaeli_cell_select'] = 'select';
$lang_text['anaeli_nofirm'] = 'not specified';
$lang_text['anaeli_noreseller'] = 'A reseller has not yet been created on this system.';
$lang_text['anaeli_title1'] = 'Select reseller to change';
$lang_text['anaelo2_error1'] = 'Reseller <b>$VAR[0]</b> has not been deleted.';
$lang_text['anaelo2_error2'] = '<b>$VAR[0]</b> users have been assigned to the reseller <b>$VAR[1]</b>. You can only delete resellers if they no longer have users assigned to them. Please delete the reseller\'s users or assign them to another reseller.';
$lang_text['anaelo2_error3'] = 'Reseller <b>$VAR[0]</b> has been deleted.';
$lang_text['anaelo2_errortitle'] = 'Notice:';
$lang_text['anaelo_button1'] = 'Ok';
$lang_text['anaelo_descr1'] = 'Please confirm that you want to delete reseller <b>$VAR[0]</b>. <br> No users are assigned to this reseller.';
$lang_text['anaelo_error1'] = '<b>$VAR[0]</b> users have been assigned to the reseller<b>$VAR[1]</b>. You can only delete resellers if they no longer have users assigned to them. Please delete the reseller\'s users or assign them to another reseller.';
$lang_text['anaelo_error2'] = 'There are no resellers specified';
$lang_text['anaelo_text1'] = 'Yes, delete reseller <b>$VAR[0]</b>.';
$lang_text['anaelo_text2'] = 'No, do not delete reseller <b>$VAR[0]</b>.';
$lang_text['anaelo_title1'] = 'Delete reseller';
$lang_text['anaepe2_error1'] = 'If you have entered a value in a definable field, you must also specify a name for this field.';
$lang_text['anaepe2_error2'] = 'The personal data of reseller <b>$VAR[0]</b> have been changed.';
$lang_text['anaepe2_errortitle'] = 'Notice:';
$lang_text['anaepe_button1'] = 'Save data';
$lang_text['anaepe_cell_address'] = 'Address';
$lang_text['anaepe_cell_cid'] = 'Customer ID';
$lang_text['anaepe_cell_city'] = 'ZIP &amp; City';
$lang_text['anaepe_cell_descr1'] = 'If the reseller\'s data change, the reseller can inform you so that you can change the data. (Only completed fields will be displayed.)';
$lang_text['anaepe_cell_description'] = 'Label';
$lang_text['anaepe_cell_email'] = 'E-mail address';
$lang_text['anaepe_cell_fax'] = 'Fax';
$lang_text['anaepe_cell_firm'] = 'Company';
$lang_text['anaepe_cell_input'] = 'Input';
$lang_text['anaepe_cell_name'] = 'Name';
$lang_text['anaepe_cell_tel'] = 'Telephone';
$lang_text['anaepe_cell_title1'] = 'Do you want to display this information in the reseller section?';
$lang_text['anaepe_cell_userdeffields'] = 'Definable fields';
$lang_text['anaepe_descr1'] = 'You can enter personal data for a reseller in this section. These data may be useful in case changes need to be made at a later date, in case of support requests, technical problems and the like.';
$lang_text['anaepe_reseller'] = 'Reseller:';
$lang_text['anaepe_title1'] = 'Change reseller';
$lang_text['anaepw2_error2'] = 'The two new passwords do not match. Please complete the form again.';
$lang_text['anaepw2_error3'] = 'Your password must consist of at least 6 characters and no more than 12 characters. Please complete the form again.';
$lang_text['anaepw2_error4'] = 'The password for reseller &quot;<b>$VAR[0]</b>&quot; has been changed.';
$lang_text['anaepw2_errortitle'] = 'Notice:';
$lang_text['anaepw_button1'] = 'Change password';
$lang_text['anaepw_cell_pw1'] = 'New password';
$lang_text['anaepw_cell_pw2'] = 'Re-enter password';
$lang_text['anaepw_cell_reseller'] = 'Reseller';
$lang_text['anaepw_descr1'] = 'Please fill in the form below and confirm with &quot;Change password&quot;. This password gives the reseller access to the reseller and user sections.';
$lang_text['anaepw_title1'] = 'Change reseller password';
$lang_text['anaesp2_error1'] = 'This reseller does not exist.';
$lang_text['anaesp2_error2'] = 'No changes have been made.';
$lang_text['anaesp2_error3'] = 'Reseller <b>$VAR[0]</b> and assigned users have been locked.';
$lang_text['anaesp2_error4'] = 'Reseller <b>$VAR[0]</b> and assigned users have been unlocked.';
$lang_text['anaesp2_errortitle'] = 'Notice:';
$lang_text['anaesp_button1'] = 'Next';
$lang_text['anaesp_descr1'] = 'Reseller <b>$VAR[0]</b> has <b>$VAR[1]</b> users that will be locked as well if the reseller is locked.</P><P>A locked reseller can no longer log onto the Confixx interface. The reseller\'s users\' Internet pages, Confixx interface and the users\' POP3 boxes will be locked as well.';
$lang_text['anaesp_descr2'] = 'Reseller <b>$VAR[0]</b> has already been locked.';
$lang_text['anaesp_text1'] = 'Do you really want to lock reseller <b>$VAR[0]</b>?';
$lang_text['anaesp_text2'] = 'Do you want to unlock reseller <b>$VAR[0]</b> and its users again?';
$lang_text['anaesp_title1'] = 'Lock reseller data';
$lang_text['anaesp_title2'] = 'Unlock reseller data';
$lang_text['anan2_button1'] = 'Next';
$lang_text['anan2_cell_address'] = 'Address';
$lang_text['anan2_cell_cid'] = 'Customer ID';
$lang_text['anan2_cell_city'] = 'City';
$lang_text['anan2_cell_country'] = 'Country';
$lang_text['anan2_cell_descr1'] = '<b><i><font face="Arial, Helvetica, sans-serif" size="-1">Display this information in the reseller section?</font></i></b><font face="Arial, Helvetica, sans-serif" size="-1"><br>(Only completed fields will be displayed.)</font><br>';
$lang_text['anan2_cell_description'] = 'Label';
$lang_text['anan2_cell_email'] = 'E-mail address';
$lang_text['anan2_cell_fax'] = 'Fax';
$lang_text['anan2_cell_firm'] = 'Company';
$lang_text['anan2_cell_firstname'] = 'First name';
$lang_text['anan2_cell_gender'] = 'Gender';
$lang_text['anan2_cell_gender1'] = 'Male';
$lang_text['anan2_cell_gender2'] = 'Female';
$lang_text['anan2_cell_input'] = 'Input';
$lang_text['anan2_cell_name'] = 'Last name';
$lang_text['anan2_cell_tel'] = 'Telephone';
$lang_text['anan2_cell_userdeffields'] = 'Definable fields';
$lang_text['anan2_cell_zip'] = 'Zip';
$lang_text['anan2_descr1'] = 'You can enter the personal data of a reseller in this section. These data may be useful in case changes need to be made at a later date, in case of support requests, technical problems and the like. These data can also be used as information for the reseller if you specify that these data are to be displayed in the reseller section.';
$lang_text['anan2_descr2'] = '<b><br>Input</b><br>If you do not want to set a limit, please enter the value &quot;<b>-1</b>&quot; in the corresponding field. If you do not want a service to be available, please enter &quot;<b>0</b>&quot; in the corresponding field.';
$lang_text['anan2_error1'] = 'You cannot set the maximum number of users to unlimited and set a limit at the same time.';
$lang_text['anan2_error10'] = 'You cannot set the maximum number of MySQL databases to unlimited and set a limit at the same time.';
$lang_text['anan2_error11'] = 'You have entered an incorrect value in the number of possible users. Please enter only whole numbers.';
$lang_text['anan2_error12'] = 'Please enter a whole number in maximum storage space.';
$lang_text['anan2_error13'] = 'You must assign at least 1 MB storage space to a reseller, not to exceed 2,000 GB.';
$lang_text['anan2_error14'] = 'You cannot set the maximum number of cron jobs to unlimited and set a limit at the same time.';
$lang_text['anan2_error15'] = 'You cannot set the maximum number of national domains to unlimited and set a limit at the same time.';
$lang_text['anan2_error16'] = 'Please enter a valid number for the maximum number of e-mail autoresponders.';
$lang_text['anan2_error17'] = 'You must authorize at least as many e-mail addresses as POP3 boxes.';
$lang_text['anan2_error18'] = 'You must authorize at least as many e-mail addresses as e-mail autoresponders.';
$lang_text['anan2_error19'] = 'You must authorize at least as many domains as users.';
$lang_text['anan2_error2'] = 'You cannot set the maximum storage space to unlimited and set a limit at the same time.';
$lang_text['anan2_error20'] = 'Please enter a valid number for the maximum number of FTP users.';
$lang_text['anan2_error21'] = 'Please enter a valid number for the upper limit on traffic.';
$lang_text['anan2_error22'] = 'Please enter a valid number for the upper limit on traffic.';
$lang_text['anan2_error23'] = 'Please enter a valid number for the maximum number of domains.';
$lang_text['anan2_error24'] = 'Please enter a valid number for the maximum number of sub-domains.';
$lang_text['anan2_error25'] = 'The number of wildcard sub-domains may not exceed the number of users the reseller is authorized to create, as each user can only use one wildcard sub-domain.';
$lang_text['anan2_error26'] = 'The number of wildcard sub-domains may not exceed the number of sub-domains the reseller is authorized to assign.';
$lang_text['anan2_error27'] = 'Please enter a valid number for the maximum number of MySQL databases.';
$lang_text['anan2_error28'] = 'You can authorize Shell access for the reseller only if the reseller is allowed to use FTP as well.';
$lang_text['anan2_error29'] = 'You can install standard CGI scripts only if you activate Perl for the user as well.';
$lang_text['anan2_error3'] = 'You cannot set the maximum number of POP3 boxes to unlimited and set a limit at the same time.';
$lang_text['anan2_error30'] = 'You must activate MySQL to authorize the reseller to assign external MySQL access.';
$lang_text['anan2_error31'] = 'You must activate PHP if you want to activate PHP upload.';
$lang_text['anan2_error32'] = 'You must activate DNS in order to activate DNR.';
$lang_text['anan2_error33'] = 'You have entered an incorrect value for the number of cron jobs. Please enter only integers.';
$lang_text['anan2_error34'] = 'You cannot set the maximum number of cron jobs to unlimited and set a limit at the same time.';
$lang_text['anan2_error35'] = 'You have entered an incorrect value for the number of national domains. Please enter only integers.';
$lang_text['anan2_error36'] = 'You cannot set the maximum number of national domains to unlimited and set a limit at the same time.';
$lang_text['anan2_error37'] = 'You cannot set the maximum number of mailing lists to unlimited and set a limit at the same time.';
$lang_text['anan2_error38'] = 'You have entered an incorrect value for the number of mailing lists. Please enter only integers.';
$lang_text['anan2_error39'] = 'Primary name server was entered incorrectly';
$lang_text['anan2_error4'] = 'You cannot set the maximum number of e-mail addresses to unlimited and set a limit at the same time.';
$lang_text['anan2_error40'] = 'Secondary name server was entered incorrectly';
$lang_text['anan2_error41'] = 'You cannot set the maximum number of wildcard sub-domains to unlimited and set a limit at the same time.';
$lang_text['anan2_error42'] = 'You cannot set the maximum number of at-domains to unlimited and set a limit at the same time.';
$lang_text['anan2_error43'] = 'Please enter a valid number for the maximum number of wildcard sub-domains.';
$lang_text['anan2_error44'] = 'Please enter a valid number for the maximum number of at-domains.';
$lang_text['anan2_error45'] = 'You cannot set the maximum number of shared domains to unlimited and set a limit at the same time.';
$lang_text['anan2_error46'] = 'Please enter a valid number for the maximum number of shared domains.';
$lang_text['anan2_error5'] = 'You cannot set the maximum number of e-mail addresses to unlimited and set a limit at the same time.';
$lang_text['anan2_error6'] = 'You cannot set the maximum number of FTP users to unlimited and set a limit at the same time.';
$lang_text['anan2_error7'] = 'You cannot allow additional FTP users when FTP has been deactivated.';
$lang_text['anan2_error8'] = 'You cannot set the maximum number of domains to unlimited and set a limit at the same time.';
$lang_text['anan2_error9'] = 'You cannot set the maximum number of sub-domains to unlimited and set a limit at the same time.';
$lang_text['anan2_error_ms_12'] = 'Please enter a whole number in maximum mail space.';
$lang_text['anan2_error_ms_2'] = 'You cannot set the maximum mail space to unlimited and set a limit at the same time.';
$lang_text['anan2_error_ms_7'] = 'You cannot set mail space  when Mail quota has been deactivated.';
$lang_text['anan2_error_ms_8'] = 'You has set mail space = 0 and turned on mailquota service. That mean user couldn\'t create an email box.';
$lang_text['anan2_passwd_descr'] = 'Leave password fields empty to generate random password';
$lang_text['anan2_title1'] = 'Create reseller';
$lang_text['anan3_button1'] = 'Next';
$lang_text['anan3_cell_description'] = 'Label';
$lang_text['anan3_cell_input'] = 'Input';
$lang_text['anan3_cell_ip'] = 'IP addresses';
$lang_text['anan3_cell_question1'] = 'Which IP address should be used as standard IP for <br> the reseller?';
$lang_text['anan3_cell_text1'] = 'Make multiple selections by pressing the &lt;ctrl&gt;-key and a mouse button.';
$lang_text['anan3_cell_text2'] = 'No other IP addresses available.';
$lang_text['anan3_descr1'] = 'You can choose from the list which IP addresses will be available to the reseller.';
$lang_text['anan3_error1'] = 'If you have entered a value in a definable field, you must also specify a name for this field.';
$lang_text['anan3_error2'] = 'To use DNR you have to fill in firstname, name, address, zip, city, country, telephone and email.';
$lang_text['anan3_pns'] = 'Primary nameserver';
$lang_text['anan3_select_stdip'] = 'Standard server IP';
$lang_text['anan3_sns'] = 'Secondary nameserver';
$lang_text['anan3_title1'] = 'Create reseller';
$lang_text['anan4_button1'] = 'Send';
$lang_text['anan4_cell_senderemail'] = 'Sender\'s e-mail address';
$lang_text['anan4_cell_sendername'] = 'Name of sender';
$lang_text['anan4_cell_sendto'] = 'To';
$lang_text['anan4_cell_subject'] = 'Subject';
$lang_text['anan4_cell_text'] = 'Text';
$lang_text['anan4_cell_title1'] = 'Send e-mail to new reseller.';
$lang_text['anan4_error1'] = 'You cannot set the maximum number of users to unlimited and set a limit at the same time.';
$lang_text['anan4_error10'] = 'You cannot set the maximum number of MySQL databases to unlimited and set a limit at the same time.';
$lang_text['anan4_error11'] = 'You can allow standard CGI scripts only if you activate Perl for the reseller as well.';
$lang_text['anan4_error12'] = 'You can authorize Shell access for the reseller only if the reseller is allowed to use FTP as well.';
$lang_text['anan4_error13'] = 'The reseller could not be created because the reseller\'s account name could not be determined. Please try again.';
$lang_text['anan4_error16'] = 'You cannot set the maximum number of shared domains to unlimited and set a limit at the same time.';
$lang_text['anan4_error2'] = 'You cannot set the maximum storage space to unlimited and set a limit at the same time.';
$lang_text['anan4_error3'] = 'You cannot set the maximum number of POP3 boxes to unlimited and set a limit at the same time.';
$lang_text['anan4_error4'] = 'You cannot set the maximum number of e-mail addresses to unlimited and set a limit at the same time.';
$lang_text['anan4_error5'] = 'You cannot set the maximum number of e-mail autoresponders to unlimited and set a limit at the same time.';
$lang_text['anan4_error6'] = 'You cannot set the maximum number of FTP users to unlimited and set a limit at the same time.';
$lang_text['anan4_error7'] = 'You cannot allow additional FTP users when FTP has been deactivated.';
$lang_text['anan4_error8'] = 'You cannot set the maximum number of domains to unlimited and set a limit at the same time.';
$lang_text['anan4_error9'] = 'You cannot set the maximum number of sub-domains to unlimited and set a limit at the same time.';
$lang_text['anan4_error_ms_2'] = 'You cannot set the maximum mail space to unlimited and set a limit at the same time.';
$lang_text['anan4_error_ms_7'] = 'You cannot set Mail space when Mail quota has been deactivated.';
$lang_text['anan4_hilfecode'] = '<font size="+1" face="Arial, Helvetica, sans-serif"><b>Confixx help</b></font><p><font size="-1" face="Arial, Helvetica, sans-serif">If you have problems setting up your web space account, your provider will be glad to help you.</font></p>';
$lang_text['anan4_password'] = 'Password:';
$lang_text['anan4_reseller'] = 'Reseller:';
$lang_text['anan4_title1'] = 'New reseller has been created';
$lang_text['anan_back'] = 'Back';
$lang_text['anan_button1'] = 'Next';
$lang_text['anan_cell_atdomains'] = 'At-domains';
$lang_text['anan_cell_autoresponder'] = 'Number of e-mail autoresponders';
$lang_text['anan_cell_cgi'] = 'CGI / Perl';
$lang_text['anan_cell_coldfusion'] = 'ColdFusion';
$lang_text['anan_cell_cron'] = 'Cron jobs';
$lang_text['anan_cell_description'] = 'Description';
$lang_text['anan_cell_dirlist'] = 'Directory listing';
$lang_text['anan_cell_dnr'] = 'DNR';
$lang_text['anan_cell_dns'] = 'DNS';
$lang_text['anan_cell_domains'] = 'Number of domains';
$lang_text['anan_cell_email'] = 'Number of e-mail addresses';
$lang_text['anan_cell_errorfiles'] = 'Directories with error files';
$lang_text['anan_cell_frontpage'] = 'FrontPage Support';
$lang_text['anan_cell_ftp'] = 'FTP';
$lang_text['anan_cell_ftpusers'] = 'Number of FTP users';
$lang_text['anan_cell_idn'] = 'National domains';
$lang_text['anan_cell_input'] = 'Input';
$lang_text['anan_cell_limit'] = 'Limit';
$lang_text['anan_cell_maillist'] = 'Mailing lists';
$lang_text['anan_cell_maximum'] = 'maximum';
$lang_text['anan_cell_modpython'] = 'Module mod_python';
$lang_text['anan_cell_mysql'] = 'MySQL Databases';
$lang_text['anan_cell_mysqlext'] = 'External MySQL access';
$lang_text['anan_cell_php'] = 'PHP';
$lang_text['anan_cell_phpupload'] = 'PHP upload';
$lang_text['anan_cell_pop3'] = 'Number of POP3 mail boxes';
$lang_text['anan_cell_pwdir'] = 'PW-protected directories';
$lang_text['anan_cell_shell'] = 'Shell access';
$lang_text['anan_cell_space'] = 'Storage space';
$lang_text['anan_cell_spamfilter'] = 'Spam filter';
$lang_text['anan_cell_ssi'] = 'SSI';
$lang_text['anan_cell_ssl'] = 'SSL';
$lang_text['anan_cell_stdscripts'] = 'Standard CGI scripts';
$lang_text['anan_cell_subdomains'] = 'Creatable sub-domains';
$lang_text['anan_cell_traffic'] = 'Traffic contained';
$lang_text['anan_cell_users'] = 'Maximum number of users';
$lang_text['anan_cell_wap'] = 'WAP';
$lang_text['anan_cell_webalizer'] = 'Webalizer / Stats';
$lang_text['anan_cell_webftp'] = 'WebFTP';
$lang_text['anan_cell_webmail'] = 'WebMail';
$lang_text['anan_cell_wildcard'] = 'Wildcard sub-domains';
$lang_text['anan_descr1'] = '<b><br>Input</b><br>If you do not want to set a limit, please enter the value &quot;<b>-1</b>&quot; in that field. If you do not want a feature to be available for the reseller, please enter &quot;<b>0</b>&quot; in the corresponding field.';
$lang_text['anan_descr2'] = '<b>Limit</b><br>You can set a limit for certain areas. This prevents the reseller from exceeding the specified maximum limit. If a limit has not been specified, the reseller can exceed the stated limit. In this case, you and the reseller will be informed accordingly.';
$lang_text['anan_title1'] = 'Create reseller';
$lang_text['anem2_error1'] = 'The data have been saved to the database.';
$lang_text['anem2_errortitle'] = 'Notice:';
$lang_text['anem_button1'] = 'Apply';
$lang_text['anem_cell_senderemail'] = 'Sender\'s e-mail address';
$lang_text['anem_cell_sendername'] = 'Name of sender';
$lang_text['anem_cell_subject'] = 'Subject';
$lang_text['anem_cell_text'] = 'Text';
$lang_text['anem_cell_title1'] = 'E-mail template';
$lang_text['anem_cell_varemail'] = 'E-mail address of sender*';
$lang_text['anem_cell_varfirm'] = 'Company of reseller*';
$lang_text['anem_cell_varname'] = 'Name of reseller*';
$lang_text['anem_cell_varpassword'] = 'Reseller password';
$lang_text['anem_cell_varreseller'] = 'Username of new reseller';
$lang_text['anem_descr1'] = 'After creating a reseller, you can send an e-mail directly to the new reseller. This e-mail will automatically be completed with the new reseller data.';
$lang_text['anem_descr2'] = '* Can be used only if personal data have been entered when reseller was created.';
$lang_text['anem_title1'] = 'E-mail template';
$lang_text['anem_title2'] = 'Include the following variables in your text:';
$lang_text['anin2_error1'] = 'The data have been saved to the database.';
$lang_text['anin2_errortitle'] = 'Notice:';
$lang_text['anin_button1'] = 'Save';
$lang_text['anin_button2'] = 'Reset to default';
$lang_text['anin_cell_filename'] = 'File name';
$lang_text['anin_cell_title1'] = 'HTML code of the standard page';
$lang_text['anin_cell_varuser'] = 'Username of new user';
$lang_text['anin_descr1'] = 'When creating a user, a home page is set up in the user\'s home directory. In this section you can save the default page preset for current resellers. The resellers can change this page.';
$lang_text['anin_descr2'] = 'Click <a class=data href="anbieter_index_vorschau.php" target="_blank">here</a>, to see the current standard index page.';
$lang_text['anin_title1'] = 'Standard index page';
$lang_text['anin_title2'] = 'Include the following variables in your text:';
$lang_text['anku2_button1'] = 'Ok';
$lang_text['anku2_confirmation1'] = 'Please confirm that you want the listed users of reseller <b>$VAR[0]</b> to be moved to reseller <b>$VAR[1]</b> .';
$lang_text['anku2_confirmation2'] = 'An IP address must also be moved from reseller <b>$VAR[0]</b> to reseller <b>$VAR[1]</b>.';
$lang_text['anku2_confirmation3'] = ' $VAR[0] IP addresses must also be moved from reseller <b>$VAR[1]</b> to reseller <b>$VAR[2]</b>.';
$lang_text['anku2_confirmation4'] = 'Please confirm that user <b>$VAR[0]</b> of reseller <b>$VAR[1]</b> is to be moved to reseller <b>$VAR[2]</b> .';
$lang_text['anku2_confirmation5'] = ' <b>An IP address</b> must also be moved from reseller <b>$VAR[0]</b> to reseller <b>$VAR[1]</b>.';
$lang_text['anku2_descr1'] = '<b>Yes</b> Move user ';
$lang_text['anku2_descr2'] = '<b>No</b> Do not move user ';
$lang_text['anku2_error1'] = 'The target reseller does not exist.';
$lang_text['anku2_error2'] = 'The source or target reseller has been locked. Users cannot be moved to or from locked resellers.';
$lang_text['anku2_error3'] = 'Reseller <b>$VAR[0]</b> does not exist.';
$lang_text['anku2_error4'] = 'Reseller <b>$VAR[0]</b> has not been assigned any users.';
$lang_text['anku2_error5'] = 'Target reseller and source reseller may not be identical.';
$lang_text['anku2_error6'] = 'This user does not exist.';
$lang_text['anku2_error7'] = 'User <b>$VAR[0]</b> has already been assigned to reseller $VAR[1].';
$lang_text['anku2_forbidden'] = 'Unable to move user <b>$VAR[0]</b> from reseller <b>res0</b>.';
$lang_text['anku2_title1'] = 'User assignment';
$lang_text['anku3_error1'] = 'No changes have been made.';
$lang_text['anku3_error10'] = 'Reseller <b>$VAR[0]</b> has been assigned user <b>$VAR[1]</b> of reseller <b>$VAR[2]</b>. Traffic generated by this user will be assigned to reseller <b>$VAR[0]</b> from now on.';
$lang_text['anku3_error2'] = 'The target reseller does not exist.';
$lang_text['anku3_error3'] = 'The source or target reseller has been locked. Users cannot be moved to or from locked resellers.';
$lang_text['anku3_error4'] = 'You want to assign reseller <b>$VAR[0]</b> $VAR[1] users. However, reseller can only accept $VAR[2] users as reseller\'s user limit would be exceeded otherwise.';
$lang_text['anku3_error5'] = 'Sorry, reseller <b>$VAR[0]</b> does not exist.';
$lang_text['anku3_error6'] = 'Sorry, reseller <b>$VAR[0]</b> has not been assigned any users.';
$lang_text['anku3_error7'] = 'Reseller <b>$VAR[0]</b> has been assigned all users of reseller <b>$VAR[1]</b>. Traffic generated by these users will be assigned to reseller <b>$VAR[0]</b> from now on.';
$lang_text['anku3_error8'] = 'This user does not exist.';
$lang_text['anku3_error9'] = 'You want to assign reseller <b>$VAR[0]</b> $VAR[1] users. However, reseller can only accept $VAR[2] users as reseller\'s user limit would be exceeded otherwise.';
$lang_text['anku3_errortitle'] = 'Notice:';
$lang_text['anku_button1'] = 'Move';
$lang_text['anku_button2'] = 'Move';
$lang_text['anku_cell_sourceres1'] = 'From reseller';
$lang_text['anku_cell_targetres1'] = 'To reseller';
$lang_text['anku_cell_targetres2'] = 'To reseller';
$lang_text['anku_cell_title1'] = 'Assign all users to another reseller';
$lang_text['anku_cell_title2'] = 'Move individual users';
$lang_text['anku_cell_user'] = 'User';
$lang_text['anku_descr1'] = 'A reseller\'s users can be assigned to a different reseller in this section.';
$lang_text['anku_descr2'] = 'Locked resellers cannot have any users assigned to them; they must first be unlocked.';
$lang_text['anku_descr3'] = 'No resellers have been created.';
$lang_text['anku_no_user'] = 'There are no users to moving.';
$lang_text['anku_title1'] = 'User assignment';
$lang_text['anku_users'] = 'Users';
$lang_text['anmy_cell_comment'] = 'Comment';
$lang_text['anmy_cell_db'] = 'Database';
$lang_text['anmy_cell_ext'] = 'external access';
$lang_text['anmy_cell_external'] = 'E';
$lang_text['anmy_cell_false'] = 'deactivated';
$lang_text['anmy_cell_reseller'] = 'Reseller';
$lang_text['anmy_cell_true'] = 'activated';
$lang_text['anmy_cell_user'] = 'User';
$lang_text['anmy_descr1'] = 'Following is an overview of your users MySQL databases. In &quot;External access&quot; you can see whether other servers can access the database.';
$lang_text['anmy_descr2'] = 'Click on the link next to the database to allow or block access by external servers.';
$lang_text['anmy_descr3'] = 'Please contact your server admin to allow or block access to a database by external servers.';
$lang_text['anmy_state_external'] = 'external';
$lang_text['anmy_state_local'] = 'local';
$lang_text['anmy_title'] = 'MySQL databases';
$lang_text['anmydb_error1'] = 'Access status of database &quot;<b>$VAR[0]</b>&quot; has been modified.';
$lang_text['anmydb_error2'] = 'Access status of database &quot;<b>$VAR[0]</b>&quot; has not been modified.';
$lang_text['anmydb_errortitle'] = 'Notice:';
$lang_text['anmydb_errortitle2'] = 'Error:';
$lang_text['anru2_button1'] = 'Send to selected recipients';
$lang_text['anru2_descr1'] = 'Your e-mail will be sent to all selected recipients.';
$lang_text['anru2_descr2'] = 'Add or remove individual entries by clicking on them while pressing <i><b>&lt;Ctrl&gt;</b></i> on your keyboard.';
$lang_text['anru2_error1'] = 'There are no resellers for whom an e-mail address has been specified.';
$lang_text['anru2_error2'] = 'Please complete all fields.';
$lang_text['anru2_title1'] = 'Circular to all resellers';
$lang_text['anru3_error1'] = 'The e-mail will be sent to the resellers.';
$lang_text['anru3_errortitle'] = 'Notice:';
$lang_text['anru_button1'] = 'Next';
$lang_text['anru_cell_senderemail'] = 'Sender\'s e-mail address';
$lang_text['anru_cell_sendername'] = 'Name of sender';
$lang_text['anru_cell_sendto'] = 'To';
$lang_text['anru_cell_sendtodescr'] = 'Select on the next page';
$lang_text['anru_cell_subject'] = 'Subject';
$lang_text['anru_cell_text'] = 'Text';
$lang_text['anru_cell_title1'] = 'Send e-mail to all resellers.';
$lang_text['anru_descr1'] = 'You can send an e-mail to all resellers whose e-mail address you have entered in personal data.';
$lang_text['anru_descr2'] = 'Duplicate e-mail addresses will be filtered out.';
$lang_text['anru_title1'] = 'Circular to all resellers';
$lang_text['anse_error1'] = 'The e-mail has been sent to the reseller.';
$lang_text['anse_errortitle'] = 'Notice:';
$lang_text['anst_descr1'] = 'In this section you can create, manage and delete resellers. In &quot;User assignment&quot; you can assign users to a different reseller.';
$lang_text['anst_descr2'] = 'You can also use your admin password to log on using a reseller in the reseller section.';
$lang_text['anst_title1'] = 'Manage reseller';
$lang_text['catch_locked'] = 'The domain &quot;$VAR[0]&quot; has been locked.';
$lang_text['catch_not_avlbl'] = 'The domain &quot;$VAR[0]&quot; is not available.';
$lang_text['catch_not_avlbl_ssl'] = 'The domain &quot;$VAR[0]&quot; is not available by https.';
$lang_text['cm_back'] = 'Back';
$lang_text['cm_edit'] = 'edit';
$lang_text['cm_help'] = 'You can add customizable menus that will be shown to users or resellers. First you should add top-level menu(s). Next you should click "items" link and configure sub-menus. You can use ##username## to insert username of reseller or user into link of sub-menu.';
$lang_text['cm_help_head'] = 'Customizable menus';
$lang_text['cm_in_frame'] = 'in frame';
$lang_text['cm_in_frame_switch_off'] = 'The link is opened in frame. Click to open the link in new window';
$lang_text['cm_in_frame_switch_on'] = 'The link is opened in new Window. Click to open the link in frame';
$lang_text['cm_items'] = '$VAR[0] menu item(s)';
$lang_text['cm_link'] = 'Link';
$lang_text['cm_noitems'] = 'There are no sub-menus yet.';
$lang_text['cm_nomenus'] = 'There are no customizable menus yet.';
$lang_text['cm_overview'] = 'Overview';
$lang_text['cm_parameters'] = 'You can use ##username## to insert username of reseller or user into link.';
$lang_text['cm_path'] = 'Sub-menus in $VAR[1] menu "$VAR[0]"';
$lang_text['cm_path_reseller'] = 'reseller';
$lang_text['cm_path_user'] = 'user';
$lang_text['cm_reseller'] = 'Reseller';
$lang_text['cm_text'] = 'Text';
$lang_text['cm_user'] = 'User';
$lang_text['cm_usertype'] = 'User type';
$lang_text['cm_wronghref'] = 'href field is empty';
$lang_text['cm_wrongid'] = 'incorrect parameter menublock_id';
$lang_text['cm_wronglabel'] = 'incorrect text that should be used for menu';
$lang_text['confixx_version'] = 'Confixx version';
$lang_text['delete_area'] = 'Delete';
$lang_text['dnshelp_descr1'] = 'You can set the primary and secondary nameserver of the resellet.';
$lang_text['dnshelp_descr2'] = 'You can make the base configuration for all DNS records.<br>Special settings concerning only one reseller or domain could be made with <b>DNS special</b>.';
$lang_text['dnshelp_descr3'] = '<b><font color="#CC0000">Important:</font></b><font color="#CC0000"> Take special care when making changes. An incorrect setting in the DNS records can halt the nameserver.</font>';
$lang_text['dnshelp_descr4'] = '<b><font color="#CC0000">Important:</font></b><font color="#CC0000"> Take special care when making changes. An incorrect setting in the DNS records can halt the nameserver.</font>';
$lang_text['dnshelp_title1'] = 'Change reseller';
$lang_text['dnshelp_title2'] = 'change DNS template';
$lang_text['dnshelp_title3'] = 'change DNS entry';
$lang_text['dnshelp_title4'] = 'change DNS entry';
$lang_text['eibl2_error1'] = 'The data have been saved to the database.';
$lang_text['eibl2_errortitle'] = 'Notice:';
$lang_text['eibl_addnew'] = 'Add new domain to the black list';
$lang_text['eibl_baddomain'] = 'Incorrect name of domain';
$lang_text['eibl_button1'] = 'Apply settings';
$lang_text['eibl_delconfirm'] = 'Delete selected domains ?';
$lang_text['eibl_descr1'] = 'In this section you can specify the domains that may not be created using Confixx. You should enter any domains that have not been created with Confixx.';
$lang_text['eibl_domain'] = 'Domain';
$lang_text['eibl_errorhas'] = 'The domain(s) <b>$VAR[0]</b> is(are) already present.';
$lang_text['eibl_errortitle'] = 'Error:';
$lang_text['eibl_ok'] = 'OK';
$lang_text['eibl_title1'] = 'Domain blacklist';
$lang_text['eibl_todelete'] = 'Delete';
$lang_text['eidb2_error1'] = 'The data have been saved to the database.';
$lang_text['eidb2_error2'] = 'Please, specify correct path to phpMyAdmin.';
$lang_text['eidb2_errortitle'] = 'Notice:';
$lang_text['eidb_button1'] = 'Apply settings';
$lang_text['eidb_cell_host'] = 'Host:';
$lang_text['eidb_cell_password'] = 'Password:';
$lang_text['eidb_cell_phpmyadmindir'] = 'phpMyAdmin path';
$lang_text['eidb_cell_phpmyadminlink'] = 'Do you want to link phpMyAdmin path to the user section?';
$lang_text['eidb_cell_user'] = 'User:';
$lang_text['eidb_descr1'] = 'In this section,  you can specify whether a link to phpMyAdmin should be displayed in the user section.';
$lang_text['eidb_mysql'] = 'MySQL';
$lang_text['eidb_title1'] = 'Database settings';
$lang_text['eidnspan_title1'] = 'Please select a reseller to edit his DNS-entrys.';
$lang_text['eidnspdoae_cell_title1'] = 'Edit DNS for $VAR[0]';
$lang_text['eidnspdosu_cell_text1'] = 'Client';
$lang_text['eidnspdosu_cell_text2'] = 'Name (if available )';
$lang_text['eidnspdosu_cell_text3'] = 'Domain';
$lang_text['eidnspdosu_cell_text4'] = 'select';
$lang_text['eidnspdosu_cell_text5'] = 'DNS-entry for';
$lang_text['eidntpdoae_cell_text1'] = 'for all domains of the reseller';
$lang_text['eidntpdoae_cell_text2'] = 'only for new domains of the reseller';
$lang_text['eidntpdoae_cell_text7'] = 'Reseller';
$lang_text['eidntpdoae_cell_title1'] = 'Edit DNS-template for $VAR[0]';
$lang_text['eidntpdoae_error'] = 'Your DNS template must consist of no more than 65 kB of text.';
$lang_text['eidntpdoae_savedns'] = 'Save DNS';
$lang_text['eidntpdoae_title12'] = 'change DNS template';
$lang_text['eidntpdoae_title13'] = 'Set new DNS entrys for all clients of the reseller.';
$lang_text['eidntpdoae_title2'] = 'You can use the following variables: ';
$lang_text['eidntpdoae_title3'] = 'Domain';
$lang_text['eidntpdoae_title4'] = 'IP-Address';
$lang_text['eidntpdoae_title5'] = 'Primary nameserver';
$lang_text['eidntpdoae_title6'] = 'Secondary nameserver';
$lang_text['eiht_button1'] = 'Next';
$lang_text['eiht_cell_additionalentries'] = 'httpd additional entries for';
$lang_text['eiht_cell_allreseller'] = 'change all resellers';
$lang_text['eiht_cell_domain'] = 'change a domain';
$lang_text['eiht_cell_onereseller'] = 'change a reseller';
$lang_text['eiht_cell_title1'] = 'Please select an action';
$lang_text['eiht_cell_user'] = 'change a user';
$lang_text['eiht_test'] = 'Test';
$lang_text['eiht_title1'] = 'Change special httpd entries';
$lang_text['eiht_warning'] = '<b><font color="#CC0000">Important:</font></b><font color="#CC0000"> Take special care when making changes. An incorrect setting in the virtual hosts can halt the web server.</font>';
$lang_text['eihtan_button1'] = 'change';
$lang_text['eihtan_cell_reseller'] = 'Reseller';
$lang_text['eihtan_descr1'] = 'Please select a reseller whose httpd entries you wish to change.';
$lang_text['eihtan_title1'] = 'Change special httpd entries';
$lang_text['eihtanae_button1'] = 'save';
$lang_text['eihtanae_cell_domain'] = 'Domain';
$lang_text['eihtanae_cell_text1'] = 'set for all of reseller\'s domains';
$lang_text['eihtanae_cell_text2'] = 'set for all of reseller\'s domains without an entry';
$lang_text['eihtanae_cell_text3'] = 'set for all of reseller\'s domains to be created in the future';
$lang_text['eihtanae_cell_title1'] = 'change additional httpd entry for $VAR[0]';
$lang_text['eihtanae_cell_username'] = 'Username of user';
$lang_text['eihtanae_title1'] = 'Change special httpd entries';
$lang_text['eihtanae_title2'] = 'You can use the following variables:';
$lang_text['eihtanaesp_error1'] = 'The data have been saved.';
$lang_text['eihtanaesp_error2'] = '<br>The following domains have not been changed:<br><br>$VAR[0]';
$lang_text['eihtanaesp_errortitle1'] = 'Notice:';
$lang_text['eihtdo_button1'] = 'search';
$lang_text['eihtdo_cell_domain'] = 'Domain';
$lang_text['eihtdo_descr1'] = 'please select a domain whose httpd entries you wish to change.';
$lang_text['eihtdo_descr2'] = 'If your entry is not clear or if there are several hits, a list will be displayed.';
$lang_text['eihtdo_title1'] = 'Change special httpd entries';
$lang_text['eihtdoae_button1'] = 'save';
$lang_text['eihtdoae_cell_dir'] = 'Install directory';
$lang_text['eihtdoae_cell_domain'] = 'Domain';
$lang_text['eihtdoae_cell_title1'] = 'change additional httpd entry for $VAR[0]';
$lang_text['eihtdoae_cell_username'] = 'Username of user';
$lang_text['eihtdoae_title1'] = 'Change special httpd entries';
$lang_text['eihtdoae_title2'] = 'You can use the following variables:';
$lang_text['eihtdoaesp_error1'] = 'The data have been saved.';
$lang_text['eihtdoaesp_errortitle'] = 'Notice:';
$lang_text['eihtdosu_cell_domain'] = 'Domain';
$lang_text['eihtdosu_cell_reseller'] = 'Reseller';
$lang_text['eihtdosu_cell_select'] = 'select';
$lang_text['eihtdosu_cell_user'] = 'User';
$lang_text['eihtdosu_title1'] = 'Change special httpd entries';
$lang_text['eihtfw_error1'] = 'Please select an action.';
$lang_text['eihtku_button1'] = 'search';
$lang_text['eihtku_cell_user'] = 'User';
$lang_text['eihtku_descr1'] = 'Please select a user whose httpd entries you wish to change.';
$lang_text['eihtku_descr2'] = 'If your entry is not clear or if there are several hits, a list will be displayed.';
$lang_text['eihtku_title1'] = 'Change special httpd entries';
$lang_text['eihtkuae_button1'] = 'save';
$lang_text['eihtkuae_cell_domain'] = 'Domain';
$lang_text['eihtkuae_cell_text1'] = 'set for all of user\'s subdomains';
$lang_text['eihtkuae_cell_text2'] = 'set for all of user\'s domains without an entry';
$lang_text['eihtkuae_cell_text3'] = 'set for all of user\'s domains to be created in the future';
$lang_text['eihtkuae_cell_title1'] = 'change additional httpd entry for $VAR[0]';
$lang_text['eihtkuae_cell_username'] = 'Username of user';
$lang_text['eihtkuae_title1'] = 'Change special httpd entries';
$lang_text['eihtkuae_title2'] = 'You can use the following variables:';
$lang_text['eihtkuaesp_error1'] = 'The data have been saved.';
$lang_text['eihtkuaesp_error2'] = '<br>The following domains have not been changed:<br><br>';
$lang_text['eihtkuaesp_errortitle1'] = 'Notice:';
$lang_text['eihtkusu_cell_domains'] = 'Domain(s)';
$lang_text['eihtkusu_cell_name'] = 'Name (if specified)';
$lang_text['eihtkusu_cell_reseller'] = 'Reseller';
$lang_text['eihtkusu_cell_select'] = 'select';
$lang_text['eihtkusu_cell_user'] = 'User';
$lang_text['eihtkusu_error1'] = 'No user found.';
$lang_text['eihtkusu_nodomain'] = 'no domain';
$lang_text['eihtkusu_noname'] = 'not specified';
$lang_text['eihtkusu_title1'] = 'Change special httpd entries';
$lang_text['eihtseae_button1'] = 'save';
$lang_text['eihtseae_cell_dir'] = 'Install directory';
$lang_text['eihtseae_cell_domain'] = 'Domain';
$lang_text['eihtseae_cell_text1'] = 'set for all domains';
$lang_text['eihtseae_cell_text2'] = 'set for all domains without an entry';
$lang_text['eihtseae_cell_text3'] = 'set for all domains to be created in the future';
$lang_text['eihtseae_cell_title1'] = 'change additional httpd entry for entire server';
$lang_text['eihtseae_cell_username'] = 'Username of user';
$lang_text['eihtseae_title1'] = 'Change special httpd entries';
$lang_text['eihtseae_title2'] = 'You can use the following variables:';
$lang_text['eihtseaesp_error1'] = 'The data have been saved.';
$lang_text['eihtseaesp_error2'] = '<br>The following domains have not been changed:<br>';
$lang_text['eihtseaesp_errortitle1'] = 'Notice:';
$lang_text['eiin2_error1'] = 'Please enter a number greater than zero for the main script.';
$lang_text['eiin2_error2'] = 'The data have been saved to the database.';
$lang_text['eiin2_errortitle'] = 'Notice:';
$lang_text['eiin2_notice'] = 'The value of "$VAR[1]" parameter has been rounded to the nearest number divisible by "$VAR[0]" parameter.';
$lang_text['eiin_button1'] = 'Cancel';
$lang_text['eiin_button2'] = 'Apply';
$lang_text['eiin_cell_backup'] = 'Backup data from master';
$lang_text['eiin_cell_event'] = 'Event';
$lang_text['eiin_cell_from'] = 'from';
$lang_text['eiin_cell_immediatereload'] = 'Do you want to reload the web server immediately after new user has been created?';
$lang_text['eiin_cell_interval'] = 'Once per ...';
$lang_text['eiin_cell_period'] = 'Time period';
$lang_text['eiin_cell_runnow'] = 'Execute now';
$lang_text['eiin_cell_scriptdu'] = 'Determine used storage space';
$lang_text['eiin_cell_scriptemail'] = 'E-mail aliases';
$lang_text['eiin_cell_scriptftptraffic'] = 'Measure FTP traffic';
$lang_text['eiin_cell_scripthttpdreload'] = 'Web server reload';
$lang_text['eiin_cell_scriptiptraffic'] = 'Measure IP traffic';
$lang_text['eiin_cell_scriptmaillist'] = 'Check maillists';
$lang_text['eiin_cell_scriptmailtraffic'] = 'Measure mail traffic';
$lang_text['eiin_cell_scriptmain'] = 'Confixx Main';
$lang_text['eiin_cell_scriptwebtraffic'] = 'Measure web traffic';
$lang_text['eiin_cell_to'] = 'to';
$lang_text['eiin_checknewver'] = 'Check for new version';
$lang_text['eiin_descr1'] = 'In this section, specify the intervals in which to execute the various services of the Confixx update script.';
$lang_text['eiin_descr2'] = 'Apache will only be restarted and the Virtusertable (e-mail addresses) will only be rewritten when needed. <br><br>If you want to execute a service once when starting the Confixx update script, whether it is needed or not and regardless of how the intervals are set, then select &quot;Execute now&quot; for this service.';
$lang_text['eiin_descr3'] = '<b><i>Hint:</i></b> If you want the script to be executed only once per day, e.g. at 3 a.m., set the time period to 3 a.m. to 4 a.m. and set the interval to more than 60 minutes. If you select a shorter interval, the script will be executed at least twice during the specified time period.';
$lang_text['eiin_every_hours'] = 'every $VAR[0] hour(s)';
$lang_text['eiin_title1'] = 'Update intervals';
$lang_text['eiin_title2'] = 'Settings';
$lang_text['eiip_button1'] = 'Enter';
$lang_text['eiip_cell_action'] = 'Action';
$lang_text['eiip_cell_delete'] = 'delete';
$lang_text['eiip_cell_ip'] = 'IP address';
$lang_text['eiip_cell_reseller'] = 'Reseller';
$lang_text['eiip_cell_status'] = 'Status';
$lang_text['eiip_cell_title1'] = 'Add IP addresses';
$lang_text['eiip_cell_user'] = 'User';
$lang_text['eiip_confirm_delete'] = 'Are you sure to delete %d IP-addresses';
$lang_text['eiip_descr1'] = 'In this section you determine which IP address can be assigned to resellers and their users. If an IP address has already been assigned to a reseller or user, it will be displayed here.';
$lang_text['eiip_descr2'] = 'Click <a class=data href="einstellungen_ip_auto.php">here</a> to get a list of all the IP addresses set up on this server.';
$lang_text['eiip_nothing_to_do'] = 'Any ip-addresses is not specified';
$lang_text['eiip_status_to_off'] = 'Free this ip';
$lang_text['eiip_status_to_on'] = 'Use this ip';
$lang_text['eiip_status_unknown'] = 'Status is unknown';
$lang_text['eiip_title1'] = 'Set IP addresses';
$lang_text['eiip_title2'] = 'IP list';
$lang_text['eiip_title3'] = 'Reread';
$lang_text['eiipau2_error1'] = 'The following changes have been made:<br><br>';
$lang_text['eiipau2_error2'] = 'IP address <b>$VAR[0]</b> has been deleted';
$lang_text['eiipau2_error3'] = 'and removed from reseller <b>$VAR[0]</b>.<br>';
$lang_text['eiipau2_error4'] = 'IP address <b>$VAR[0]</b> could not be deleted because user <b>$VAR[1]</b> is using it.<br>';
$lang_text['eiipau2_error5'] = 'IP address <b>$VAR[0]</b> is invalid and has not been created.<br>';
$lang_text['eiipau2_error6'] = 'IP address <b>$VAR[0]</b> has been added to the list.<br>';
$lang_text['eiipau2_errortitle'] = 'Notice:';
$lang_text['eiipau_apply_request'] = 'Apply request';
$lang_text['eiipau_button1'] = 'Apply selection';
$lang_text['eiipau_button2'] = 'Update IP list';
$lang_text['eiipau_cell_selection'] = 'Selection';
$lang_text['eiipau_cell_title1'] = 'IP address';
$lang_text['eiipau_descr1'] = 'The following list shows all IP addresses (with the exception of the standard IP address) available on this server. Select the IP addresses that Confixx may assign to resellers and their users.';
$lang_text['eiipau_descr2'] = 'No local IP addresses available.';
$lang_text['eiipau_title1'] = 'Select IP addresses';
$lang_text['eiipau_title2'] = 'IP list, last updated:';
$lang_text['eiipauup_error1'] = 'Your IP list will be updated the next time the update script is executed.';
$lang_text['eiipauup_errortitle'] = 'Notice:';
$lang_text['eiiplo_button1'] = 'Yes, delete.';
$lang_text['eiiplo_descr1'] = 'The IP address $VAR[0] is assigned to a reseller. Do you really want to delete it?';
$lang_text['eiiplo_error1'] = 'The IP address has been deleted.';
$lang_text['eiiplo_error2'] = 'The IP address could not be deleted because it is still being used.';
$lang_text['eiiplo_errortitle'] = 'Notice:';
$lang_text['eiiplo_title1'] = 'Delete IP addresses';
$lang_text['eiipne_error1'] = 'At least one of the IP addresses is invalid.';
$lang_text['eiipne_error2'] = 'The data have been saved to the database.';
$lang_text['eiipne_errortitle'] = 'Notice:';
$lang_text['eila_editmessage'] = 'Edit message';
$lang_text['eila_msg_apply'] = 'Apply';
$lang_text['eila_msg_cancel'] = 'Cancel';
$lang_text['eila_sendmodealways'] = 'always';
$lang_text['eila_sendmodenever'] = 'never';
$lang_text['eila_sendmodeonce'] = 'once';
$lang_text['eiqu2_error1'] = 'The data have been saved to the database.';
$lang_text['eiqu2_error2'] = 'The hard quota must be more then the soft quota.';
$lang_text['eiqu2_errortitle'] = 'Notice:';
$lang_text['eiqu_button1'] = 'Apply settings';
$lang_text['eiqu_cell_ftp'] = 'FTP quota:';
$lang_text['eiqu_cell_hard'] = 'Hard quota:';
$lang_text['eiqu_cell_pop'] = 'POP3 quota:';
$lang_text['eiqu_cell_soft'] = 'Soft quota:';
$lang_text['eiqu_cell_text'] = 'Apply to existing accounts';
$lang_text['eiqu_cell_text2'] = 'Apply to existing accounts with custom quota settings';
$lang_text['eiqu_descr1'] = 'In this section you can specify how much storage space should be available for POP3 accounts and additional FTP accounts. Enter the value &quot;0&quot; if you do not want to limit the storage space.';
$lang_text['eiqu_title1'] = 'Mail Quota settings';
$lang_text['eisd2_error1'] = 'The new standard domain is invalid.';
$lang_text['eisd2_error2'] = 'The standard domain has been changed.';
$lang_text['eisd2_error3'] = 'The new standard IP is invalid.';
$lang_text['eisd2_error4'] = 'The new standard IP cannot be used as it has been cleared to be assigned to resellers. Please remove this IP address in settings &gt; IP addresses';
$lang_text['eisd2_errortitle'] = 'Notice:';
$lang_text['eisd_btn_change'] = 'Change domain';
$lang_text['eisd_cell_all'] = 'Apply new standard domain to existing users, too?';
$lang_text['eisd_cell_disable'] = 'Disable Standard domain';
$lang_text['eisd_cell_ip'] = 'Standard IP';
$lang_text['eisd_cell_std'] = 'Standard domain';
$lang_text['eisd_cell_yes'] = 'Yes';
$lang_text['eisd_descr1'] = 'In this section you can change the standard server domain. <b>Please do not make any changes unless you know exactly what you are doing and if a change is truly necessary.</b>';
$lang_text['eisd_descr2'] = 'If you want the change to be applied to new users only and not to current users, please unselect the corresponding field.';
$lang_text['eisd_title'] = 'Standard domain';
$lang_text['eist_descr1'] = 'This section allows you to make general server settings.';
$lang_text['eist_descr2'] = 'Before creating the first reseller, you should make initial settings in this section.';
$lang_text['eist_title1'] = 'Settings';
$lang_text['g_error'] = 'Error';
$lang_text['g_light'] = '<P><font face="Arial, Helvetica, sans-serif" size="-1"><b>This feature is not available in Confixx-Light.</b></font></P>';
$lang_text['g_no'] = 'No';
$lang_text['g_nolimit'] = 'Unlimited';
$lang_text['g_save'] = 'Save';
$lang_text['g_title'] = 'Confixx&reg; - Server Administration';
$lang_text['g_yes'] = 'Yes';
$lang_text['httpd_option_desc'] = 'Example: <br/>Name - safe_mode<br/> Value - on <br/> httpd entry - php_admin_flag safe_mode on<br/>In httpd entry area you can use ##user## (replaced with username e.g. web0), ##domain## ,##user_home##(replaced with user home base e.g. /var/www)';
$lang_text['httpd_options_add'] = 'Add httpd option';
$lang_text['httpd_options_change'] = 'Change httpd option';
$lang_text['httpd_options_del_no'] = 'No, do not delete httpd option $VAR[0].';
$lang_text['httpd_options_del_yes'] = 'Yes, delete httpd option $VAR[0].';
$lang_text['httpd_options_delete'] = 'Delete httpd options';
$lang_text['httpd_options_delete_confirm'] = 'Do you really want to delete <b>$VAR[0]</b> option. <br> For <b>$VAR[1]</b> domains the option will be unset';
$lang_text['httpd_options_delete_error1'] = 'You can not delete value(s) $VAR[0] because it has(ve) been defined for certain domains.';
$lang_text['httpd_options_deleted'] = 'Httpd options have been deleted.';
$lang_text['httpd_options_do_not_change'] = 'Do not change';
$lang_text['httpd_options_empty'] = 'There is not an httpd option selected';
$lang_text['httpd_options_help_text'] = 'Httpd options are named web server configuration pieces that you can set/remove with a click for a domain/user/reseller<br/> You can entrust a httpd option to reseler/user with a hosting plan. Be careful with unsecure options do not allow to manage them by resellers/users';
$lang_text['httpd_options_not_set'] = 'default';
$lang_text['httpd_options_warn_res_users'] = 'You cannot turn off these options <b>$VAR[0]</b> because the reseller has already assigned them to users.';
$lang_text['inst_adminpw'] = 'Admin password';
$lang_text['inst_btn_next'] = 'Next &gt;&gt;';
$lang_text['inst_dbpwroot'] = 'Database root password';
$lang_text['inst_dbpwuser'] = 'Database user password';
$lang_text['inst_error1'] = 'The root password is invalid.<br>';
$lang_text['inst_error2'] = 'The database root password is invalid.<br>';
$lang_text['inst_error3'] = 'The database user password is invalid.<br>';
$lang_text['inst_error4'] = 'The admin password is invalid.<br>';
$lang_text['inst_error5'] = 'Please complete all fields marked with *.';
$lang_text['inst_hostname'] = 'Host name';
$lang_text['inst_logindomain'] = 'Login domain';
$lang_text['inst_loginip'] = 'Login IP';
$lang_text['inst_pwroot'] = 'root password';
$lang_text['inst_stddomain'] = 'Standard domain';
$lang_text['inst_stdip'] = 'Standard IP';
$lang_text['inst_title'] = 'Confixx installation complete';
$lang_text['install_email'] = 'To complete the Confixx postconfiguration process, please fill in personal data below';
$lang_text['install_postconf_header'] = 'To complete the Confixx postconfiguration process, please fill in the input fields below';
$lang_text['install_question_ip_pns'] = 'What is the IP address of your primary nameserver?';
$lang_text['install_question_ip_sns'] = 'What is the IP address of your secondary nameserver?';
$lang_text['install_question_stddomain'] = 'Under which domain do you want all user pages to be accessible?';
$lang_text['install_question_stdip'] = 'Which IP address do you want to use as the default IP for the virtual hosts?';
$lang_text['ipr_accept'] = 'Accept';
$lang_text['ipr_accepted'] = 'Accepted';
$lang_text['ipr_addnew'] = 'Add new IP';
$lang_text['ipr_denied'] = 'Denied';
$lang_text['ipr_error2'] = 'The IP address &quot;<b>$VAR[0]</b>&quot; has been set up.';
$lang_text['ipr_help_head'] = 'IP restrictions';
$lang_text['ipr_help_text'] = 'Restrict access to the web interface by specifying an IP address wildcard (asterisks are allowed, e.g. "128.0.0.*") and a policy (accept/deny)';
$lang_text['ipr_incorrectip'] = 'Incorrect IP address: $VAR[0]';
$lang_text['ipr_ipaddress'] = 'IP address';
$lang_text['ipr_norestrictions'] = 'No restrictions - web interface is accessible from anywhere.';
$lang_text['ipr_switch_accept'] = 'The ip is denied. Click to accept';
$lang_text['ipr_switch_deny'] = 'The ip is accepted. Click to deny';
$lang_text['ipr_yourip'] = '$VAR[0] is used by your PC. Once logged out, you will not be able to login from that box anymore. Please, confirm that you would like to deny access from it.';
$lang_text['ipr_yourips'] = '$VAR[0] are used by your PC. Once logged out, you will not be able to login from that box anymore. Please, confirm that you would like to deny access from it.';
$lang_text['kulc_status_active'] = 'The user is active. Click to lock.';
$lang_text['kulc_status_locked'] = 'The user is locked. Click to unlock.';
$lang_text['kulc_title1'] = 'Change user\'s status';
$lang_text['m_general'] = 'General';
$lang_text['m_help'] = 'Help';
$lang_text['m_master'] = 'Master';
$lang_text['m_overview'] = 'Overview';
$lang_text['m_reseller'] = 'Reseller';
$lang_text['m_resellers'] = 'Resellers';
$lang_text['m_server'] = 'Servers';
$lang_text['m_server_setup'] = 'Server settings';
$lang_text['m_sessions'] = 'Sessions';
$lang_text['m_setup'] = 'Settings';
$lang_text['m_stats'] = 'Stats';
$lang_text['m_system'] = 'System';
$lang_text['m_userinfo'] = 'User info';
$lang_text['ma_billing'] = 'Billing';
$lang_text['ma_changepw'] = 'Change password';
$lang_text['ma_confixxserver'] = 'Confixx server';
$lang_text['ma_custommenu'] = 'Customizable menus';
$lang_text['ma_iprestriction'] = 'IP restrictions';
$lang_text['ma_license'] = 'Licensing information';
$lang_text['ma_personalinfo'] = 'Personal information';
$lang_text['ma_reslogin'] = 'Reseller login';
$lang_text['ma_selectlanguage'] = 'Language/Design';
$lang_text['ma_server'] = 'Select Confixx server';
$lang_text['ma_servermessages'] = 'Messages';
$lang_text['ma_sessionlist'] = 'Session list';
$lang_text['ma_userlogin'] = 'User login';
$lang_text['man_createreseller'] = 'Create reseller';
$lang_text['man_editreseller'] = 'Change reseller';
$lang_text['man_indexsetup'] = 'Index setup';
$lang_text['man_mailing'] = 'Circular';
$lang_text['man_mailsetup'] = 'E-mail setup';
$lang_text['man_mysql'] = 'MySQL';
$lang_text['man_usersowner'] = 'User assignment';
$lang_text['me_blacklist'] = 'Domain blacklist';
$lang_text['me_db'] = 'Databases';
$lang_text['me_dnsspezial'] = 'DNS special';
$lang_text['me_dnstemplate'] = 'DNS template';
$lang_text['me_dnstemplate1'] = 'Confixx';
$lang_text['me_httpd'] = 'httpd special';
$lang_text['me_interval'] = 'Update intervals';
$lang_text['me_ip'] = 'IP addresses';
$lang_text['me_limitalert'] = 'Limits alert';
$lang_text['me_quota'] = 'Quota';
$lang_text['me_ssl'] = 'Shared SSL';
$lang_text['me_stddomain'] = 'Standard domain';
$lang_text['me_webapp'] = 'Web applications';
$lang_text['mk_ssl'] = 'SSL';
$lang_text['ms_resellerstats'] = 'Reseller stats';
$lang_text['ms_traffic'] = 'Traffic';
$lang_text['ms_userstats'] = 'User stats';
$lang_text['ms_versions'] = 'Versions';
$lang_text['reg_index_licence'] = 'License key';
$lang_text['reg_index_sid'] = 'Server ID';
$lang_text['reg_index_sn'] = 'Serial number';
$lang_text['reg_index_status'] = 'Status';
$lang_text['reg_index_status2'] = 'Licence status';
$lang_text['reg_index_title'] = 'General information (Confixx server)';
$lang_text['reg_index_valid'] = 'Valid until';
$lang_text['reg_index_version'] = 'Version';
$lang_text['reg_menu_admin'] = 'Administrator panel';
$lang_text['reg_menu_licence'] = 'Licensing information';
$lang_text['reg_menu_register'] = 'Unlock license';
$lang_text['reg_menu_setup'] = 'Direct entry';
$lang_text['reg_register_desc'] = 'Please click on &quot;<b>Next &gt;&gt;</b>&quot; to contact the registration server. After your license key has been created, you will get back to save the license key.';
$lang_text['reg_register_desc2'] = 'If you want to register manually, please use the following server ID:.';
$lang_text['reg_register_error'] = 'Registration failed. Please start execution of the counter script.';
$lang_text['reg_register_next'] = 'Next &gt;&gt;';
$lang_text['reg_register_title'] = 'Unlock license (Confixx server)';
$lang_text['reg_setup_desc'] = 'Please click on &quot;<b>Next &gt;&gt;</b>&quot; to save the license key and to activate Confixx.';
$lang_text['reg_setup_error1'] = 'Not all fields have been completed.';
$lang_text['reg_setup_error2'] = 'The data have been saved to the database.';
$lang_text['reg_setup_errortitle'] = 'Notice:';
$lang_text['reg_setup_licence'] = 'License key';
$lang_text['reg_setup_next'] = 'Next &gt;&gt;';
$lang_text['reg_setup_sn'] = 'Serial number';
$lang_text['reg_setup_title'] = 'Enter license key (Confixx server)';
$lang_text['reg_setup_valid'] = 'Valid until';
$lang_text['reg_setup_version'] = 'Version';
$lang_text['sehtsp_apply'] = 'Apply';
$lang_text['sehtsp_back'] = 'Back';
$lang_text['sehtsp_example'] = 'Source';
$lang_text['sehtsp_result'] = 'Result';
$lang_text['sehtsp_special'] = 'Httpd special';
$lang_text['sehtsp_title'] = 'Test of httpd special';
$lang_text['server_anlegen_fehler_dbname'] = 'Incorrect database name';
$lang_text['server_anlegen_fehler_ip'] = 'Incorrect server ip/dns name';
$lang_text['server_anlegen_fehler_name'] = 'Incorrect server name';
$lang_text['server_anlegen_fehler_noconnect'] = 'Unable to connect to the database';
$lang_text['server_anlegen_fehler_password'] = 'Incorrect password';
$lang_text['server_anlegen_fehler_user'] = 'Incorrect database user name';
$lang_text['sk_default_skin'] = 'The reseller\'s default skin';
$lang_text['sl_ip'] = 'IP';
$lang_text['sl_lastactive'] = 'Last active';
$lang_text['sl_logintime'] = 'Login time';
$lang_text['sl_users'] = 'Users';
$lang_text['stde_activated'] = 'Activated';
$lang_text['stde_cell_address'] = 'Address';
$lang_text['stde_cell_assign_mailspace'] = 'Assigned mail space';
$lang_text['stde_cell_atdomains'] = 'At-domains';
$lang_text['stde_cell_autoresponder'] = 'E-mail autoresponders';
$lang_text['stde_cell_awstats'] = 'AWstats / Stats';
$lang_text['stde_cell_cid'] = 'Customer ID';
$lang_text['stde_cell_city'] = 'ZIP &amp; City';
$lang_text['stde_cell_coldfusion'] = 'ColdFusion';
$lang_text['stde_cell_cron'] = 'Cron jobs';
$lang_text['stde_cell_date'] = 'Created on:';
$lang_text['stde_cell_dbext'] = 'External MySQL access';
$lang_text['stde_cell_dirlist'] = 'Directory listing';
$lang_text['stde_cell_domains'] = 'Number of domains';
$lang_text['stde_cell_dudb'] = 'Storage space used by databases';
$lang_text['stde_cell_dufiles'] = 'Storage space used by files';
$lang_text['stde_cell_email'] = 'E-mail addresses';
$lang_text['stde_cell_errorfiles'] = 'Own error files';
$lang_text['stde_cell_fax'] = 'Fax';
$lang_text['stde_cell_firm'] = 'Company';
$lang_text['stde_cell_frontpage'] = 'FrontPage';
$lang_text['stde_cell_ftp'] = 'FTP';
$lang_text['stde_cell_ftpusers'] = 'Additional FTP users';
$lang_text['stde_cell_idn'] = 'National domains';
$lang_text['stde_cell_ipaddress'] = 'IP addresses';
$lang_text['stde_cell_maillist'] = 'Mailing lists';
$lang_text['stde_cell_max_mailspace'] = 'Maximum mail space';
$lang_text['stde_cell_maxspace'] = 'Maximum storage space';
$lang_text['stde_cell_maxtraffic'] = 'Maximum traffic';
$lang_text['stde_cell_modpython'] = 'Module mod_python';
$lang_text['stde_cell_mysql'] = 'MySQL databases';
$lang_text['stde_cell_name'] = 'Name';
$lang_text['stde_cell_numberofips'] = 'Assigned';
$lang_text['stde_cell_perl'] = 'Perl';
$lang_text['stde_cell_php'] = 'PHP';
$lang_text['stde_cell_phpupload'] = 'PHP upload';
$lang_text['stde_cell_pop3'] = 'POP3 boxes';
$lang_text['stde_cell_scponly'] = 'Scp/SFTP';
$lang_text['stde_cell_shell'] = 'Shell';
$lang_text['stde_cell_spamfilter'] = 'Spam filter';
$lang_text['stde_cell_ssi'] = 'SSI';
$lang_text['stde_cell_ssl'] = 'SSL';
$lang_text['stde_cell_stdscripts'] = 'Standard CGI scripts';
$lang_text['stde_cell_subdomains'] = 'Sub-domains';
$lang_text['stde_cell_tel'] = 'Telephone';
$lang_text['stde_cell_trafficemail'] = 'E-mail traffic included';
$lang_text['stde_cell_trafficftp'] = 'FTP traffic included';
$lang_text['stde_cell_traffichttpd'] = 'Web traffic included';
$lang_text['stde_cell_trafficlink'] = 'Comprehensive overview';
$lang_text['stde_cell_used_mailspace'] = 'Used mail space';
$lang_text['stde_cell_usedips'] = 'Used';
$lang_text['stde_cell_usedspace'] = 'Used storage space';
$lang_text['stde_cell_usedtraffic'] = 'Used traffic';
$lang_text['stde_cell_users'] = 'Number of users';
$lang_text['stde_cell_vusedspace'] = 'Assigned storage space';
$lang_text['stde_cell_wap'] = 'WAP';
$lang_text['stde_cell_webalizer'] = 'Webalizer / Stats';
$lang_text['stde_cell_webftp'] = 'WebFTP';
$lang_text['stde_cell_webmail'] = 'WebMail';
$lang_text['stde_cell_wildcard'] = 'Wildcard sub-domains';
$lang_text['stde_deactivated'] = 'Deactivated';
$lang_text['stde_locked'] = 'This reseller has been locked.';
$lang_text['stde_mailspace'] = 'Mail space usage';
$lang_text['stde_title1'] = 'Reseller details';
$lang_text['stde_title2'] = 'User data';
$lang_text['stde_title3'] = 'Overview';
$lang_text['stde_title4'] = 'Storage space usage';
$lang_text['stde_title5'] = 'Traffic';
$lang_text['stde_title6'] = 'IP addresses';
$lang_text['stde_title7'] = 'Available services';
$lang_text['stdetr_cell_day'] = 'Day';
$lang_text['stdetr_cell_email'] = 'E-mail';
$lang_text['stdetr_cell_ftpweb'] = 'FTP / Web';
$lang_text['stdetr_cell_month'] = 'Month';
$lang_text['stdetr_cell_total'] = 'Total';
$lang_text['stdetr_descr1'] = 'This displays traffic for all the users of reseller <strong>$VAR[0]</strong> measured by Confixx on this server.';
$lang_text['stdetr_title1'] = 'Reseller details';
$lang_text['stdetr_title2'] = 'Transfer details for';
$lang_text['stdetr_title3'] = 'Transfer summary for all months';
$lang_text['stku1_error1'] = 'Please enter a search parameter for the user.';
$lang_text['stku1_error2'] = 'No user found that matches your search parameter.';
$lang_text['stku1_error3'] = 'Several users were found that match your search parameter.';
$lang_text['stku1_errortitle'] = 'Notice:';
$lang_text['stku1_nodomain'] = 'no domain';
$lang_text['stku1_nofirm'] = 'not specified';
$lang_text['stku1_noname'] = 'not specified';
$lang_text['stku2_cell_address'] = 'Address';
$lang_text['stku2_cell_autoresponder'] = 'E-mail autoresponders';
$lang_text['stku2_cell_awstats'] = 'AWstats / Stats';
$lang_text['stku2_cell_cid'] = 'Customer ID';
$lang_text['stku2_cell_city'] = 'ZIP &amp; City';
$lang_text['stku2_cell_coldfusion'] = 'ColdFusion';
$lang_text['stku2_cell_cron'] = 'Cron jobs';
$lang_text['stku2_cell_date'] = 'Created on:';
$lang_text['stku2_cell_domains'] = 'Domains';
$lang_text['stku2_cell_dudb'] = 'Storage space used by databases';
$lang_text['stku2_cell_dufiles'] = 'Storage space used by files';
$lang_text['stku2_cell_email'] = 'E-mail addresses';
$lang_text['stku2_cell_errorfiles'] = 'Own error files';
$lang_text['stku2_cell_fax'] = 'Fax';
$lang_text['stku2_cell_firm'] = 'Company';
$lang_text['stku2_cell_ftp'] = 'FTP';
$lang_text['stku2_cell_ftpusers'] = 'Additional FTP users';
$lang_text['stku2_cell_idn'] = 'National domains';
$lang_text['stku2_cell_ip'] = 'IP address';
$lang_text['stku2_cell_maillist'] = 'Mailing lists';
$lang_text['stku2_cell_maxspace'] = 'Maximum storage space';
$lang_text['stku2_cell_maxtraffic'] = 'Maximum traffic';
$lang_text['stku2_cell_mysql'] = 'MySQL databases';
$lang_text['stku2_cell_name'] = 'Name';
$lang_text['stku2_cell_perl'] = 'PERL';
$lang_text['stku2_cell_php'] = 'PHP';
$lang_text['stku2_cell_pop3'] = 'POP3 boxes';
$lang_text['stku2_cell_pwdir'] = 'Password protection';
$lang_text['stku2_cell_scponly'] = 'Scp/SFTP';
$lang_text['stku2_cell_shell'] = 'Shell';
$lang_text['stku2_cell_spamfilter'] = 'Spam filter';
$lang_text['stku2_cell_ssi'] = 'SSI';
$lang_text['stku2_cell_ssl'] = 'SSL';
$lang_text['stku2_cell_subdomains'] = 'Sub-domains';
$lang_text['stku2_cell_tel'] = 'Telephone';
$lang_text['stku2_cell_trafficemail'] = 'E-mail traffic included';
$lang_text['stku2_cell_trafficftp'] = 'FTP traffic included';
$lang_text['stku2_cell_traffichttpd'] = 'Web traffic included';
$lang_text['stku2_cell_trafficlink'] = 'Comprehensive overview';
$lang_text['stku2_cell_usedspace'] = 'Used storage space';
$lang_text['stku2_cell_usedtraffic'] = 'Used traffic';
$lang_text['stku2_cell_vusedspace'] = 'Assigned storage space';
$lang_text['stku2_cell_webalizer'] = 'Webalizer / Stats';
$lang_text['stku2_cell_webftp'] = 'WebFTP';
$lang_text['stku2_cell_webmail'] = 'WebMail';
$lang_text['stku2_cell_wildcard'] = 'Wildcard sub-domain';
$lang_text['stku2_descr1'] = 'This user has been locked.';
$lang_text['stku2_st_ip_addr'] = 'Standart IP';
$lang_text['stku2_title1'] = 'Details of user $VAR[0] of reseller $VAR[1]';
$lang_text['stku2_title2'] = 'User data';
$lang_text['stku2_title3'] = 'Overview';
$lang_text['stku2_title4'] = 'Storage space usage';
$lang_text['stku2_title5'] = 'Traffic';
$lang_text['stku2_title6'] = 'IP address';
$lang_text['stku2_title7'] = 'Available services';
$lang_text['stku3_cell_day'] = 'Day';
$lang_text['stku3_cell_email'] = 'E-mail';
$lang_text['stku3_cell_ftpweb'] = 'FTP / Web';
$lang_text['stku3_cell_month'] = 'Month';
$lang_text['stku3_cell_total'] = 'Total';
$lang_text['stku3_descr1'] = 'This displays traffic generated by user <strong>$VAR[0]</strong> measured by Confixx on this server.';
$lang_text['stku3_title1'] = 'Details of user <strong>$VAR[0]</strong>';
$lang_text['stku3_title2'] = 'Transfer details for';
$lang_text['stku3_title3'] = 'Transfer summary for all months';
$lang_text['stkun2_back'] = 'back';
$lang_text['stkun2_cell_du'] = 'Storage space';
$lang_text['stkun2_cell_email'] = 'E-mail/POP3';
$lang_text['stkun2_cell_traffic'] = 'Traffic';
$lang_text['stkun2_cell_user'] = 'User';
$lang_text['stkun2_descr1'] = 'No additional users were found that match your search parameter.';
$lang_text['stkun2_next'] = 'next';
$lang_text['stkun2_title1'] = 'User stats of your users';
$lang_text['stkun_button1'] = 'Analyze';
$lang_text['stkun_button2'] = 'Analyze';
$lang_text['stkun_cell_domains'] = 'Domain(s)';
$lang_text['stkun_cell_name'] = 'Name (if specified)';
$lang_text['stkun_cell_numberofusers'] = 'Users per page';
$lang_text['stkun_cell_overlimit'] = 'Show exceeding only';
$lang_text['stkun_cell_reseller'] = 'by reseller';
$lang_text['stkun_cell_select'] = 'select';
$lang_text['stkun_cell_sortedby'] = 'Sorted by';
$lang_text['stkun_cell_text1'] = 'User, name, company or domain name';
$lang_text['stkun_cell_title1'] = 'comprehensive stats for individual user';
$lang_text['stkun_cell_title2'] = 'Service overview of your users';
$lang_text['stkun_cell_user'] = 'User';
$lang_text['stkun_select1_users'] = 'Users';
$lang_text['stkun_select2_du'] = 'Used storage space';
$lang_text['stkun_select2_email'] = 'E-mail addresses';
$lang_text['stkun_select2_lmtraffic'] = 'Last month\'s traffic';
$lang_text['stkun_select2_pop'] = 'POP3 boxes';
$lang_text['stkun_select2_traffic'] = 'Current traffic';
$lang_text['stkun_select2_user'] = 'User';
$lang_text['stkun_select3_allresellers'] = 'All resellers';
$lang_text['stkun_title1'] = 'All user stats';
$lang_text['stssl_btn_next'] = 'Next &gt;&gt;';
$lang_text['stssl_btn_save'] = 'save';
$lang_text['stssl_cell_ca_crt'] = 'CA Certificate (optional)';
$lang_text['stssl_cell_city'] = 'City';
$lang_text['stssl_cell_common'] = 'Domain';
$lang_text['stssl_cell_countrycode'] = 'Country code';
$lang_text['stssl_cell_crs'] = 'Certificate request (CSR)';
$lang_text['stssl_cell_crt'] = 'Certificate (CRT)';
$lang_text['stssl_cell_email'] = 'E-mail address';
$lang_text['stssl_cell_firm'] = 'Company';
$lang_text['stssl_cell_privatekey'] = 'Private key';
$lang_text['stssl_cell_selfsigned'] = 'Create a self-signed certificate';
$lang_text['stssl_cell_state'] = 'State';
$lang_text['stssl_cell_title'] = 'What is available?';
$lang_text['stssl_cell_unit'] = 'Department';
$lang_text['stssl_change'] = 'Change the shared SSL certificate';
$lang_text['stssl_create'] = 'Create a shared SSL certificate';
$lang_text['stssl_crs_is_down'] = 'Certificate Request is not Certificate yet.
Certificate Request becames a Certificate after its signing by a Certificate
Authority. What are Certificate and Certificate Authority and why you should
have your Certificate Request signed you can read <a href="http://httpd.apache.org/docs-2.0/ssl/ssl_intro.html#certificates"  target="_blank" >here</a>';
$lang_text['stssl_descr1'] = 'This is shared SSL feature';
$lang_text['stssl_help_crs'] = 'Please complete the following form. Your private key and the certificate request (CSR) will automatically be generated.';
$lang_text['stssl_help_crt'] = 'Please enter your private key and certificate (CRT).';
$lang_text['stssl_key_crt_no_valid'] = 'SSL certificate and private key do not seem to match.';
$lang_text['stssl_key_crt_ok'] = 'Private key and SSL certificate are stored into database';
$lang_text['stssl_not_exists'] = 'There is not a shared SSL certificate';
$lang_text['stssl_select_crt'] = 'Private key and certificate (CRT)';
$lang_text['stssl_select_nothing'] = 'nothing available ...';
$lang_text['stssl_status'] = 'Status of the shared SSL certificate';
$lang_text['stssl_success'] = 'The shared SSL certificate is active';
$lang_text['stssl_title1'] = 'Shared SSL';
$lang_text['stssl_working'] = 'Making of the shared SSL certificate in progress';
$lang_text['stst_cell_assigned'] = 'assigned';
$lang_text['stst_cell_du'] = 'Storage space: used / assigned / max';
$lang_text['stst_cell_max'] = 'max';
$lang_text['stst_cell_reseller'] = 'Reseller';
$lang_text['stst_cell_transfer'] = 'Traffic / max';
$lang_text['stst_cell_used'] = 'used';
$lang_text['stst_cell_users'] = 'Users / max';
$lang_text['stst_descr1'] = 'No resellers have been created.';
$lang_text['stst_title1'] = 'Reseller stats of your resellers';
$lang_text['sttr_cell_day'] = 'Day';
$lang_text['sttr_cell_email'] = 'E-mail';
$lang_text['sttr_cell_ftpweb'] = 'FTP / Web';
$lang_text['sttr_cell_month'] = 'Month';
$lang_text['sttr_cell_total'] = 'Total';
$lang_text['sttr_descr1'] = 'This displays traffic for all the resellers and their users measured by Confixx on this server. This includes traffic for previously deleted resellers and users.';
$lang_text['sttr_title1'] = 'Traffic for all resellers';
$lang_text['sttr_title2'] = 'Transfer details for';
$lang_text['sttr_title3'] = 'Transfer summary for all months';
$lang_text['upd_alert_nv'] = 'Version $VAR[0] of Confixx released. See <a href="$VAR[1]">details</a>';
$lang_text['upd_description'] = 'Description';
$lang_text['upd_downloadurl'] = 'URL for download';
$lang_text['upd_homepage'] = 'Description URL';
$lang_text['upd_no_new_versions'] = 'No new versions available';
$lang_text['upd_no_newer_versions'] = 'No versions newer than the current one were detected.';
$lang_text['upd_nv_header'] = 'New version';
$lang_text['upd_releasedate'] = 'Release date';
$lang_text['upd_showall'] = 'Show all versions';
$lang_text['upd_version'] = 'Version';
$lang_text['wa_all_types'] = 'All';
$lang_text['wa_conf'] = 'Configure';
$lang_text['wa_config'] = 'configure';
$lang_text['wa_config_head'] = 'Configure';
$lang_text['wa_descr'] = 'Description';
$lang_text['wa_hash_crypt'] = 'Crypt';
$lang_text['wa_hash_md5'] = 'MD5';
$lang_text['wa_hash_mysql'] = 'MySQL';
$lang_text['wa_hash_plain'] = 'Plain';
$lang_text['wa_hash_type'] = 'Type of password hash';
$lang_text['wa_httpd_conf'] = 'httpd entry';
$lang_text['wa_name'] = 'Name';
$lang_text['wa_not_found'] = 'The Web application is not found';
$lang_text['wa_start_page'] = 'Start page';
$lang_text['wa_status'] = 'Status';
$lang_text['wa_status_active'] = 'Active';
$lang_text['wa_status_deactive'] = 'Banned';
$lang_text['wa_status_to_off'] = 'Deactivate';
$lang_text['wa_status_to_on'] = 'Activate';
$lang_text['wa_title'] = 'Web applications';
$lang_text['wa_title1'] = 'Web application';
$lang_text['wa_tools'] = 'Tools';
$lang_text['wa_type'] = 'Group';
$lang_text['wa_update'] = 'Update list';
$lang_text['wa_update_ok'] = 'The task is sheduled';
$lang_text['wa_version'] = 'Version';
$lang_text['what_server_am_i'] = 'server: ';

?>
